from onix.book.v3_0.reference.book_3_0_reference import (
    Avduration,
    AvdurationRefname,
    AvdurationShortname,
    Avitem,
    AvitemIdtype,
    AvitemIdtypeRefname,
    AvitemIdtypeShortname,
    AvitemIdentifier,
    AvitemIdentifierRefname,
    AvitemIdentifierShortname,
    AvitemType,
    AvitemTypeRefname,
    AvitemTypeShortname,
    AvitemRefname,
    AvitemShortname,
    Addressee,
    AddresseeIdtype,
    AddresseeIdtypeRefname,
    AddresseeIdtypeShortname,
    AddresseeIdentifier,
    AddresseeIdentifierRefname,
    AddresseeIdentifierShortname,
    AddresseeName,
    AddresseeNameRefname,
    AddresseeNameShortname,
    AddresseeRefname,
    AddresseeShortname,
    Affiliation,
    AffiliationRefname,
    AffiliationShortname,
    AgentIdtype,
    AgentIdtypeRefname,
    AgentIdtypeShortname,
    AgentIdentifier,
    AgentIdentifierRefname,
    AgentIdentifierShortname,
    AgentName,
    AgentNameRefname,
    AgentNameShortname,
    AgentRole,
    AgentRoleRefname,
    AgentRoleShortname,
    AlternativeName,
    AlternativeNameRefname,
    AlternativeNameShortname,
    AncillaryContent,
    AncillaryContentDescription,
    AncillaryContentDescriptionRefname,
    AncillaryContentDescriptionShortname,
    AncillaryContentType,
    AncillaryContentTypeRefname,
    AncillaryContentTypeShortname,
    AncillaryContentRefname,
    AncillaryContentShortname,
    Audience,
    AudienceCode,
    AudienceCodeType,
    AudienceCodeTypeName,
    AudienceCodeTypeNameRefname,
    AudienceCodeTypeNameShortname,
    AudienceCodeTypeRefname,
    AudienceCodeTypeShortname,
    AudienceCodeValue,
    AudienceCodeValueRefname,
    AudienceCodeValueShortname,
    AudienceCodeRefname,
    AudienceCodeShortname,
    AudienceDescription,
    AudienceDescriptionRefname,
    AudienceDescriptionShortname,
    AudienceHeadingText,
    AudienceHeadingTextRefname,
    AudienceHeadingTextShortname,
    AudienceRange,
    AudienceRangePrecision,
    AudienceRangePrecisionRefname,
    AudienceRangePrecisionShortname,
    AudienceRangeQualifier,
    AudienceRangeQualifierRefname,
    AudienceRangeQualifierShortname,
    AudienceRangeValue,
    AudienceRangeValueRefname,
    AudienceRangeValueShortname,
    AudienceRangeRefname,
    AudienceRangeShortname,
    AudienceRefname,
    AudienceShortname,
    Barcode,
    BarcodeType,
    BarcodeTypeRefname,
    BarcodeTypeShortname,
    BarcodeRefname,
    BarcodeShortname,
    BatchBonus,
    BatchBonusRefname,
    BatchBonusShortname,
    BatchQuantity,
    BatchQuantityRefname,
    BatchQuantityShortname,
    Bible,
    BibleContents,
    BibleContentsRefname,
    BibleContentsShortname,
    BiblePurpose,
    BiblePurposeRefname,
    BiblePurposeShortname,
    BibleReferenceLocation,
    BibleReferenceLocationRefname,
    BibleReferenceLocationShortname,
    BibleTextFeature,
    BibleTextFeatureRefname,
    BibleTextFeatureShortname,
    BibleTextOrganization,
    BibleTextOrganizationRefname,
    BibleTextOrganizationShortname,
    BibleVersion,
    BibleVersionRefname,
    BibleVersionShortname,
    BibleRefname,
    BibleShortname,
    BiographicalNote,
    BiographicalNoteRefname,
    BiographicalNoteShortname,
    BodyManifest,
    BodyManifestRefname,
    BodyManifestShortname,
    BodyResource,
    BodyResourceRefname,
    BodyResourceShortname,
    BookClubAdoption,
    BookClubAdoptionRefname,
    BookClubAdoptionShortname,
    Cbo,
    CboRefname,
    CboShortname,
    CitationNote,
    CitationNoteRefname,
    CitationNoteShortname,
    CitedContent,
    CitedContentType,
    CitedContentTypeRefname,
    CitedContentTypeShortname,
    CitedContentRefname,
    CitedContentShortname,
    CityOfPublication,
    CityOfPublicationRefname,
    CityOfPublicationShortname,
    CollateralDetail,
    CollateralDetailRefname,
    CollateralDetailShortname,
    Collection,
    CollectionIdtype,
    CollectionIdtypeRefname,
    CollectionIdtypeShortname,
    CollectionIdentifier,
    CollectionIdentifierRefname,
    CollectionIdentifierShortname,
    CollectionSequence,
    CollectionSequenceNumber,
    CollectionSequenceNumberRefname,
    CollectionSequenceNumberShortname,
    CollectionSequenceType,
    CollectionSequenceTypeName,
    CollectionSequenceTypeNameRefname,
    CollectionSequenceTypeNameShortname,
    CollectionSequenceTypeRefname,
    CollectionSequenceTypeShortname,
    CollectionSequenceRefname,
    CollectionSequenceShortname,
    CollectionType,
    CollectionTypeRefname,
    CollectionTypeShortname,
    CollectionRefname,
    CollectionShortname,
    ComparisonProductPrice,
    ComparisonProductPriceRefname,
    ComparisonProductPriceShortname,
    Complexity,
    ComplexityCode,
    ComplexityCodeRefname,
    ComplexityCodeShortname,
    ComplexitySchemeIdentifier,
    ComplexitySchemeIdentifierRefname,
    ComplexitySchemeIdentifierShortname,
    ComplexityRefname,
    ComplexityShortname,
    ComponentNumber,
    ComponentNumberRefname,
    ComponentNumberShortname,
    ComponentTypeName,
    ComponentTypeNameRefname,
    ComponentTypeNameShortname,
    Conference,
    ConferenceAcronym,
    ConferenceAcronymRefname,
    ConferenceAcronymShortname,
    ConferenceDate,
    ConferenceDateRefname,
    ConferenceDateShortname,
    ConferenceName,
    ConferenceNameRefname,
    ConferenceNameShortname,
    ConferenceNumber,
    ConferenceNumberRefname,
    ConferenceNumberShortname,
    ConferencePlace,
    ConferencePlaceRefname,
    ConferencePlaceShortname,
    ConferenceRole,
    ConferenceRoleRefname,
    ConferenceRoleShortname,
    ConferenceSponsor,
    ConferenceSponsorIdtype,
    ConferenceSponsorIdtypeRefname,
    ConferenceSponsorIdtypeShortname,
    ConferenceSponsorIdentifier,
    ConferenceSponsorIdentifierRefname,
    ConferenceSponsorIdentifierShortname,
    ConferenceSponsorRefname,
    ConferenceSponsorShortname,
    ConferenceTheme,
    ConferenceThemeRefname,
    ConferenceThemeShortname,
    ConferenceRefname,
    ConferenceShortname,
    ContactName,
    ContactNameRefname,
    ContactNameShortname,
    ContentAudience,
    ContentAudienceRefname,
    ContentAudienceShortname,
    ContentDate,
    ContentDateRole,
    ContentDateRoleRefname,
    ContentDateRoleShortname,
    ContentDateRefname,
    ContentDateShortname,
    ContentDetail,
    ContentDetailRefname,
    ContentDetailShortname,
    ContentItem,
    ContentItemRefname,
    ContentItemShortname,
    Contributor,
    ContributorDate,
    ContributorDateRole,
    ContributorDateRoleRefname,
    ContributorDateRoleShortname,
    ContributorDateRefname,
    ContributorDateShortname,
    ContributorDescription,
    ContributorDescriptionRefname,
    ContributorDescriptionShortname,
    ContributorPlace,
    ContributorPlaceRelator,
    ContributorPlaceRelatorRefname,
    ContributorPlaceRelatorShortname,
    ContributorPlaceRefname,
    ContributorPlaceShortname,
    ContributorReference,
    ContributorReferenceRefname,
    ContributorReferenceShortname,
    ContributorRole,
    ContributorRoleRefname,
    ContributorRoleShortname,
    ContributorStatement,
    ContributorStatementRefname,
    ContributorStatementShortname,
    ContributorRefname,
    ContributorShortname,
    CopiesSold,
    CopiesSoldRefname,
    CopiesSoldShortname,
    CopyrightOwner,
    CopyrightOwnerIdtype,
    CopyrightOwnerIdtypeRefname,
    CopyrightOwnerIdtypeShortname,
    CopyrightOwnerIdentifier,
    CopyrightOwnerIdentifierRefname,
    CopyrightOwnerIdentifierShortname,
    CopyrightOwnerRefname,
    CopyrightOwnerShortname,
    CopyrightStatement,
    CopyrightStatementRefname,
    CopyrightStatementShortname,
    CopyrightType,
    CopyrightTypeRefname,
    CopyrightTypeShortname,
    CopyrightYear,
    CopyrightYearRefname,
    CopyrightYearShortname,
    CorporateName,
    CorporateNameInverted,
    CorporateNameInvertedRefname,
    CorporateNameInvertedShortname,
    CorporateNameRefname,
    CorporateNameShortname,
    CountriesExcluded,
    CountriesExcludedRefname,
    CountriesExcludedShortname,
    CountriesIncluded,
    CountriesIncludedRefname,
    CountriesIncludedShortname,
    CountryCode,
    CountryCodeRefname,
    CountryCodeShortname,
    CountryOfManufacture,
    CountryOfManufactureRefname,
    CountryOfManufactureShortname,
    CountryOfPublication,
    CountryOfPublicationRefname,
    CountryOfPublicationShortname,
    CoverManifest,
    CoverManifestRefname,
    CoverManifestShortname,
    CoverResource,
    CoverResourceRefname,
    CoverResourceShortname,
    CurrencyCode,
    CurrencyCodeRefname,
    CurrencyCodeShortname,
    CurrencyZone,
    CurrencyZoneRefname,
    CurrencyZoneShortname,
    Date,
    DateFormat,
    DateFormatRefname,
    DateFormatShortname,
    DateRefname,
    DateShortname,
    DefaultCurrencyCode,
    DefaultCurrencyCodeRefname,
    DefaultCurrencyCodeShortname,
    DefaultLanguageOfText,
    DefaultLanguageOfTextRefname,
    DefaultLanguageOfTextShortname,
    DefaultPriceType,
    DefaultPriceTypeRefname,
    DefaultPriceTypeShortname,
    DeletionText,
    DeletionTextRefname,
    DeletionTextShortname,
    DescriptiveDetail,
    DescriptiveDetailRefname,
    DescriptiveDetailShortname,
    Discount,
    DiscountAmount,
    DiscountAmountRefname,
    DiscountAmountShortname,
    DiscountCode,
    DiscountCodeType,
    DiscountCodeTypeName,
    DiscountCodeTypeNameRefname,
    DiscountCodeTypeNameShortname,
    DiscountCodeTypeRefname,
    DiscountCodeTypeShortname,
    DiscountCodeRefname,
    DiscountCodeShortname,
    DiscountCoded,
    DiscountCodedRefname,
    DiscountCodedShortname,
    DiscountPercent,
    DiscountPercentRefname,
    DiscountPercentShortname,
    DiscountType,
    DiscountTypeRefname,
    DiscountTypeShortname,
    DiscountRefname,
    DiscountShortname,
    EditionNumber,
    EditionNumberRefname,
    EditionNumberShortname,
    EditionStatement,
    EditionStatementRefname,
    EditionStatementShortname,
    EditionType,
    EditionTypeRefname,
    EditionTypeShortname,
    EditionVersionNumber,
    EditionVersionNumberRefname,
    EditionVersionNumberShortname,
    EmailAddress,
    EmailAddressRefname,
    EmailAddressShortname,
    EndDate,
    EndDateRefname,
    EndDateShortname,
    EndTime,
    EndTimeRefname,
    EndTimeShortname,
    EpubLicense,
    EpubLicenseExpression,
    EpubLicenseExpressionLink,
    EpubLicenseExpressionLinkRefname,
    EpubLicenseExpressionLinkShortname,
    EpubLicenseExpressionType,
    EpubLicenseExpressionTypeName,
    EpubLicenseExpressionTypeNameRefname,
    EpubLicenseExpressionTypeNameShortname,
    EpubLicenseExpressionTypeRefname,
    EpubLicenseExpressionTypeShortname,
    EpubLicenseExpressionRefname,
    EpubLicenseExpressionShortname,
    EpubLicenseName,
    EpubLicenseNameRefname,
    EpubLicenseNameShortname,
    EpubLicenseRefname,
    EpubLicenseShortname,
    EpubTechnicalProtection,
    EpubTechnicalProtectionRefname,
    EpubTechnicalProtectionShortname,
    EpubUsageConstraint,
    EpubUsageConstraintRefname,
    EpubUsageConstraintShortname,
    EpubUsageLimit,
    EpubUsageLimitRefname,
    EpubUsageLimitShortname,
    EpubUsageStatus,
    EpubUsageStatusRefname,
    EpubUsageStatusShortname,
    EpubUsageType,
    EpubUsageTypeRefname,
    EpubUsageTypeShortname,
    EpubUsageUnit,
    EpubUsageUnitRefname,
    EpubUsageUnitShortname,
    Event,
    EventAcronym,
    EventAcronymRefname,
    EventAcronymShortname,
    EventDate,
    EventDateRefname,
    EventDateShortname,
    EventDescription,
    EventDescriptionRefname,
    EventDescriptionShortname,
    EventIdtype,
    EventIdtypeRefname,
    EventIdtypeShortname,
    EventIdentifier,
    EventIdentifierRefname,
    EventIdentifierShortname,
    EventName,
    EventNameRefname,
    EventNameShortname,
    EventNumber,
    EventNumberRefname,
    EventNumberShortname,
    EventOccurrence,
    EventOccurrenceRefname,
    EventOccurrenceShortname,
    EventPlace,
    EventPlaceRefname,
    EventPlaceShortname,
    EventRole,
    EventRoleRefname,
    EventRoleShortname,
    EventSponsor,
    EventSponsorIdtype,
    EventSponsorIdtypeRefname,
    EventSponsorIdtypeShortname,
    EventSponsorIdentifier,
    EventSponsorIdentifierRefname,
    EventSponsorIdentifierShortname,
    EventSponsorRefname,
    EventSponsorShortname,
    EventStatus,
    EventStatusRefname,
    EventStatusShortname,
    EventTheme,
    EventThemeRefname,
    EventThemeShortname,
    EventType,
    EventTypeRefname,
    EventTypeShortname,
    EventRefname,
    EventShortname,
    ExpectedDate,
    ExpectedDateRefname,
    ExpectedDateShortname,
    Extent,
    ExtentType,
    ExtentTypeRefname,
    ExtentTypeShortname,
    ExtentUnit,
    ExtentUnitRefname,
    ExtentUnitShortname,
    ExtentValue,
    ExtentValueRoman,
    ExtentValueRomanRefname,
    ExtentValueRomanShortname,
    ExtentValueRefname,
    ExtentValueShortname,
    ExtentRefname,
    ExtentShortname,
    FaxNumber,
    FaxNumberRefname,
    FaxNumberShortname,
    FeatureNote,
    FeatureNoteRefname,
    FeatureNoteShortname,
    FeatureValue,
    FeatureValueRefname,
    FeatureValueShortname,
    FirstPageNumber,
    FirstPageNumberRefname,
    FirstPageNumberShortname,
    FreeQuantity,
    FreeQuantityRefname,
    FreeQuantityShortname,
    FromLanguage,
    FromLanguageRefname,
    FromLanguageShortname,
    Funding,
    FundingIdtype,
    FundingIdtypeRefname,
    FundingIdtypeShortname,
    FundingIdentifier,
    FundingIdentifierRefname,
    FundingIdentifierShortname,
    FundingRefname,
    FundingShortname,
    Gender,
    GenderRefname,
    GenderShortname,
    Header,
    HeaderRefname,
    HeaderShortname,
    IdtypeName,
    IdtypeNameRefname,
    IdtypeNameShortname,
    Idvalue,
    IdvalueRefname,
    IdvalueShortname,
    Illustrated,
    IllustratedRefname,
    IllustratedShortname,
    IllustrationsNote,
    IllustrationsNoteRefname,
    IllustrationsNoteShortname,
    Imprint,
    ImprintIdtype,
    ImprintIdtypeRefname,
    ImprintIdtypeShortname,
    ImprintIdentifier,
    ImprintIdentifierRefname,
    ImprintIdentifierShortname,
    ImprintName,
    ImprintNameRefname,
    ImprintNameShortname,
    ImprintRefname,
    ImprintShortname,
    InitialPrintRun,
    InitialPrintRunRefname,
    InitialPrintRunShortname,
    InsertManifest,
    InsertManifestRefname,
    InsertManifestShortname,
    InsertPoint,
    InsertPointType,
    InsertPointTypeRefname,
    InsertPointTypeShortname,
    InsertPointValue,
    InsertPointValueRefname,
    InsertPointValueShortname,
    InsertPointRefname,
    InsertPointShortname,
    InsertResource,
    InsertResourceRefname,
    InsertResourceShortname,
    KeyNames,
    KeyNamesRefname,
    KeyNamesShortname,
    Language,
    LanguageCode,
    LanguageCodeRefname,
    LanguageCodeShortname,
    LanguageRole,
    LanguageRoleRefname,
    LanguageRoleShortname,
    LanguageRefname,
    LanguageShortname,
    LastPageNumber,
    LastPageNumberRefname,
    LastPageNumberShortname,
    LatestReprintNumber,
    LatestReprintNumberRefname,
    LatestReprintNumberShortname,
    LettersAfterNames,
    LettersAfterNamesRefname,
    LettersAfterNamesShortname,
    LevelSequenceNumber,
    LevelSequenceNumberRefname,
    LevelSequenceNumberShortname,
    ListName,
    ListNameRefname,
    ListNameShortname,
    LocationIdtype,
    LocationIdtypeRefname,
    LocationIdtypeShortname,
    LocationIdentifier,
    LocationIdentifierRefname,
    LocationIdentifierShortname,
    LocationName,
    LocationNameRefname,
    LocationNameShortname,
    MainSubject,
    MainSubjectRefname,
    MainSubjectShortname,
    MapScale,
    MapScaleRefname,
    MapScaleShortname,
    Market,
    MarketDate,
    MarketDateRole,
    MarketDateRoleRefname,
    MarketDateRoleShortname,
    MarketDateRefname,
    MarketDateShortname,
    MarketPublishingDetail,
    MarketPublishingDetailRefname,
    MarketPublishingDetailShortname,
    MarketPublishingStatus,
    MarketPublishingStatusNote,
    MarketPublishingStatusNoteRefname,
    MarketPublishingStatusNoteShortname,
    MarketPublishingStatusRefname,
    MarketPublishingStatusShortname,
    MarketRefname,
    MarketShortname,
    Measure,
    MeasureType,
    MeasureTypeRefname,
    MeasureTypeShortname,
    MeasureUnitCode,
    MeasureUnitCodeRefname,
    MeasureUnitCodeShortname,
    MeasureRefname,
    MeasureShortname,
    Measurement,
    MeasurementRefname,
    MeasurementShortname,
    MessageNote,
    MessageNoteRefname,
    MessageNoteShortname,
    MessageNumber,
    MessageNumberRefname,
    MessageNumberShortname,
    MessageRepeat,
    MessageRepeatRefname,
    MessageRepeatShortname,
    MinimumOrderQuantity,
    MinimumOrderQuantityRefname,
    MinimumOrderQuantityShortname,
    NameAsSubject,
    NameAsSubjectRefname,
    NameAsSubjectShortname,
    NameIdtype,
    NameIdtypeRefname,
    NameIdtypeShortname,
    NameIdentifier,
    NameIdentifierRefname,
    NameIdentifierShortname,
    NameType,
    NameTypeRefname,
    NameTypeShortname,
    NamesAfterKey,
    NamesAfterKeyRefname,
    NamesAfterKeyShortname,
    NamesBeforeKey,
    NamesBeforeKeyRefname,
    NamesBeforeKeyShortname,
    NewSupplier,
    NewSupplierRefname,
    NewSupplierShortname,
    NoCollection,
    NoCollectionRefname,
    NoCollectionShortname,
    NoContributor,
    NoContributorRefname,
    NoContributorShortname,
    NoEdition,
    NoEditionRefname,
    NoEditionShortname,
    NoPrefix,
    NoPrefixRefname,
    NoPrefixShortname,
    NoProduct,
    NoProductRefname,
    NoProductShortname,
    NoResource,
    NoResourceRefname,
    NoResourceShortname,
    NoSupplement,
    NoSupplementRefname,
    NoSupplementShortname,
    NotificationType,
    NotificationTypeRefname,
    NotificationTypeShortname,
    Number,
    NumberOfCopies,
    NumberOfCopiesRefname,
    NumberOfCopiesShortname,
    NumberOfIllustrations,
    NumberOfIllustrationsRefname,
    NumberOfIllustrationsShortname,
    NumberOfItemsOfThisForm,
    NumberOfItemsOfThisFormRefname,
    NumberOfItemsOfThisFormShortname,
    NumberOfPages,
    NumberOfPagesRefname,
    NumberOfPagesShortname,
    NumberRefname,
    NumberShortname,
    Onixmessage,
    OnixmessageRefname,
    OnixmessageShortname,
    OccurrenceDate,
    OccurrenceDateRole,
    OccurrenceDateRoleRefname,
    OccurrenceDateRoleShortname,
    OccurrenceDateRefname,
    OccurrenceDateShortname,
    OnHand,
    OnHandRefname,
    OnHandShortname,
    OnOrder,
    OnOrderDetail,
    OnOrderDetailRefname,
    OnOrderDetailShortname,
    OnOrderRefname,
    OnOrderShortname,
    OrderQuantityMinimum,
    OrderQuantityMinimumRefname,
    OrderQuantityMinimumShortname,
    OrderQuantityMultiple,
    OrderQuantityMultipleRefname,
    OrderQuantityMultipleShortname,
    OrderTime,
    OrderTimeRefname,
    OrderTimeShortname,
    PackQuantity,
    PackQuantityRefname,
    PackQuantityShortname,
    PageRun,
    PageRunRefname,
    PageRunShortname,
    PalletQuantity,
    PalletQuantityRefname,
    PalletQuantityShortname,
    PartNumber,
    PartNumberRefname,
    PartNumberShortname,
    Percent,
    PercentRefname,
    PercentShortname,
    PersonName,
    PersonNameInverted,
    PersonNameInvertedRefname,
    PersonNameInvertedShortname,
    PersonNameRefname,
    PersonNameShortname,
    PositionOnList,
    PositionOnListRefname,
    PositionOnListShortname,
    PositionOnProduct,
    PositionOnProductRefname,
    PositionOnProductShortname,
    PrefixToKey,
    PrefixToKeyRefname,
    PrefixToKeyShortname,
    Price,
    PriceAmount,
    PriceAmountRefname,
    PriceAmountShortname,
    PriceCode,
    PriceCodeType,
    PriceCodeTypeName,
    PriceCodeTypeNameRefname,
    PriceCodeTypeNameShortname,
    PriceCodeTypeRefname,
    PriceCodeTypeShortname,
    PriceCodeRefname,
    PriceCodeShortname,
    PriceCoded,
    PriceCodedRefname,
    PriceCodedShortname,
    PriceCondition,
    PriceConditionQuantity,
    PriceConditionQuantityType,
    PriceConditionQuantityTypeRefname,
    PriceConditionQuantityTypeShortname,
    PriceConditionQuantityRefname,
    PriceConditionQuantityShortname,
    PriceConditionType,
    PriceConditionTypeRefname,
    PriceConditionTypeShortname,
    PriceConditionRefname,
    PriceConditionShortname,
    PriceConstraint,
    PriceConstraintLimit,
    PriceConstraintLimitRefname,
    PriceConstraintLimitShortname,
    PriceConstraintStatus,
    PriceConstraintStatusRefname,
    PriceConstraintStatusShortname,
    PriceConstraintType,
    PriceConstraintTypeRefname,
    PriceConstraintTypeShortname,
    PriceConstraintUnit,
    PriceConstraintUnitRefname,
    PriceConstraintUnitShortname,
    PriceConstraintRefname,
    PriceConstraintShortname,
    PriceDate,
    PriceDateRole,
    PriceDateRoleRefname,
    PriceDateRoleShortname,
    PriceDateRefname,
    PriceDateShortname,
    PriceIdtype,
    PriceIdtypeRefname,
    PriceIdtypeShortname,
    PriceIdentifier,
    PriceIdentifierRefname,
    PriceIdentifierShortname,
    PricePartDescription,
    PricePartDescriptionRefname,
    PricePartDescriptionShortname,
    PricePer,
    PricePerRefname,
    PricePerShortname,
    PriceQualifier,
    PriceQualifierRefname,
    PriceQualifierShortname,
    PriceStatus,
    PriceStatusRefname,
    PriceStatusShortname,
    PriceType,
    PriceTypeDescription,
    PriceTypeDescriptionRefname,
    PriceTypeDescriptionShortname,
    PriceTypeRefname,
    PriceTypeShortname,
    PriceRefname,
    PriceShortname,
    PrimaryContentType,
    PrimaryContentTypeRefname,
    PrimaryContentTypeShortname,
    PrimaryPart,
    PrimaryPartRefname,
    PrimaryPartShortname,
    PrintedOnProduct,
    PrintedOnProductRefname,
    PrintedOnProductShortname,
    Prize,
    PrizeCode,
    PrizeCodeRefname,
    PrizeCodeShortname,
    PrizeCountry,
    PrizeCountryRefname,
    PrizeCountryShortname,
    PrizeJury,
    PrizeJuryRefname,
    PrizeJuryShortname,
    PrizeName,
    PrizeNameRefname,
    PrizeNameShortname,
    PrizeRegion,
    PrizeRegionRefname,
    PrizeRegionShortname,
    PrizeStatement,
    PrizeStatementRefname,
    PrizeStatementShortname,
    PrizeYear,
    PrizeYearRefname,
    PrizeYearShortname,
    PrizeRefname,
    PrizeShortname,
    Product,
    ProductAvailability,
    ProductAvailabilityRefname,
    ProductAvailabilityShortname,
    ProductClassification,
    ProductClassificationCode,
    ProductClassificationCodeRefname,
    ProductClassificationCodeShortname,
    ProductClassificationType,
    ProductClassificationTypeName,
    ProductClassificationTypeNameRefname,
    ProductClassificationTypeNameShortname,
    ProductClassificationTypeRefname,
    ProductClassificationTypeShortname,
    ProductClassificationRefname,
    ProductClassificationShortname,
    ProductComposition,
    ProductCompositionRefname,
    ProductCompositionShortname,
    ProductContact,
    ProductContactIdtype,
    ProductContactIdtypeRefname,
    ProductContactIdtypeShortname,
    ProductContactIdentifier,
    ProductContactIdentifierRefname,
    ProductContactIdentifierShortname,
    ProductContactName,
    ProductContactNameRefname,
    ProductContactNameShortname,
    ProductContactRole,
    ProductContactRoleRefname,
    ProductContactRoleShortname,
    ProductContactRefname,
    ProductContactShortname,
    ProductContentType,
    ProductContentTypeRefname,
    ProductContentTypeShortname,
    ProductForm,
    ProductFormDescription,
    ProductFormDescriptionRefname,
    ProductFormDescriptionShortname,
    ProductFormDetail,
    ProductFormDetailRefname,
    ProductFormDetailShortname,
    ProductFormFeature,
    ProductFormFeatureDescription,
    ProductFormFeatureDescriptionRefname,
    ProductFormFeatureDescriptionShortname,
    ProductFormFeatureType,
    ProductFormFeatureTypeRefname,
    ProductFormFeatureTypeShortname,
    ProductFormFeatureValue,
    ProductFormFeatureValueRefname,
    ProductFormFeatureValueShortname,
    ProductFormFeatureRefname,
    ProductFormFeatureShortname,
    ProductFormRefname,
    ProductFormShortname,
    ProductIdtype,
    ProductIdtypeRefname,
    ProductIdtypeShortname,
    ProductIdentifier,
    ProductIdentifierRefname,
    ProductIdentifierShortname,
    ProductPackaging,
    ProductPackagingRefname,
    ProductPackagingShortname,
    ProductPart,
    ProductPartRefname,
    ProductPartShortname,
    ProductRelationCode,
    ProductRelationCodeRefname,
    ProductRelationCodeShortname,
    ProductSupply,
    ProductSupplyRefname,
    ProductSupplyShortname,
    ProductRefname,
    ProductShortname,
    ProductionDetail,
    ProductionDetailRefname,
    ProductionDetailShortname,
    ProductionManifest,
    ProductionManifestRefname,
    ProductionManifestShortname,
    ProfessionalAffiliation,
    ProfessionalAffiliationRefname,
    ProfessionalAffiliationShortname,
    ProfessionalPosition,
    ProfessionalPositionRefname,
    ProfessionalPositionShortname,
    PromotionCampaign,
    PromotionCampaignRefname,
    PromotionCampaignShortname,
    PromotionContact,
    PromotionContactRefname,
    PromotionContactShortname,
    PromotionDetail,
    PromotionDetailRefname,
    PromotionDetailShortname,
    PromotionalEvent,
    PromotionalEventRefname,
    PromotionalEventShortname,
    Proximity,
    ProximityRefname,
    ProximityShortname,
    Publisher,
    PublisherIdtype,
    PublisherIdtypeRefname,
    PublisherIdtypeShortname,
    PublisherIdentifier,
    PublisherIdentifierRefname,
    PublisherIdentifierShortname,
    PublisherName,
    PublisherNameRefname,
    PublisherNameShortname,
    PublisherRepresentative,
    PublisherRepresentativeRefname,
    PublisherRepresentativeShortname,
    PublisherRefname,
    PublisherShortname,
    PublishingDate,
    PublishingDateRole,
    PublishingDateRoleRefname,
    PublishingDateRoleShortname,
    PublishingDateRefname,
    PublishingDateShortname,
    PublishingDetail,
    PublishingDetailRefname,
    PublishingDetailShortname,
    PublishingRole,
    PublishingRoleRefname,
    PublishingRoleShortname,
    PublishingStatus,
    PublishingStatusNote,
    PublishingStatusNoteRefname,
    PublishingStatusNoteShortname,
    PublishingStatusRefname,
    PublishingStatusShortname,
    Quantity,
    QuantityUnit,
    QuantityUnitRefname,
    QuantityUnitShortname,
    QuantityRefname,
    QuantityShortname,
    RowsalesRightsType,
    RowsalesRightsTypeRefname,
    RowsalesRightsTypeShortname,
    Rate,
    RateRefname,
    RateShortname,
    Rating,
    RatingLimit,
    RatingLimitRefname,
    RatingLimitShortname,
    RatingUnits,
    RatingUnitsRefname,
    RatingUnitsShortname,
    RatingRefname,
    RatingShortname,
    RecordReference,
    RecordReferenceRefname,
    RecordReferenceShortname,
    RecordSourceIdtype,
    RecordSourceIdtypeRefname,
    RecordSourceIdtypeShortname,
    RecordSourceIdentifier,
    RecordSourceIdentifierRefname,
    RecordSourceIdentifierShortname,
    RecordSourceName,
    RecordSourceNameRefname,
    RecordSourceNameShortname,
    RecordSourceType,
    RecordSourceTypeRefname,
    RecordSourceTypeShortname,
    RegionCode,
    RegionCodeRefname,
    RegionCodeShortname,
    RegionsExcluded,
    RegionsExcludedRefname,
    RegionsExcludedShortname,
    RegionsIncluded,
    RegionsIncludedRefname,
    RegionsIncludedShortname,
    Reissue,
    ReissueDate,
    ReissueDateRefname,
    ReissueDateShortname,
    ReissueDescription,
    ReissueDescriptionRefname,
    ReissueDescriptionShortname,
    ReissueRefname,
    ReissueShortname,
    RelatedMaterial,
    RelatedMaterialRefname,
    RelatedMaterialShortname,
    RelatedProduct,
    RelatedProductRefname,
    RelatedProductShortname,
    RelatedWork,
    RelatedWorkRefname,
    RelatedWorkShortname,
    ReligiousText,
    ReligiousTextFeature,
    ReligiousTextFeatureCode,
    ReligiousTextFeatureCodeRefname,
    ReligiousTextFeatureCodeShortname,
    ReligiousTextFeatureDescription,
    ReligiousTextFeatureDescriptionRefname,
    ReligiousTextFeatureDescriptionShortname,
    ReligiousTextFeatureType,
    ReligiousTextFeatureTypeRefname,
    ReligiousTextFeatureTypeShortname,
    ReligiousTextFeatureRefname,
    ReligiousTextFeatureShortname,
    ReligiousTextIdentifier,
    ReligiousTextIdentifierRefname,
    ReligiousTextIdentifierShortname,
    ReligiousTextRefname,
    ReligiousTextShortname,
    ReprintDetail,
    ReprintDetailRefname,
    ReprintDetailShortname,
    Reserved,
    ReservedRefname,
    ReservedShortname,
    ResourceContentType,
    ResourceContentTypeRefname,
    ResourceContentTypeShortname,
    ResourceFeature,
    ResourceFeatureType,
    ResourceFeatureTypeRefname,
    ResourceFeatureTypeShortname,
    ResourceFeatureRefname,
    ResourceFeatureShortname,
    ResourceFileContentDescription,
    ResourceFileContentDescriptionRefname,
    ResourceFileContentDescriptionShortname,
    ResourceFileDate,
    ResourceFileDateRole,
    ResourceFileDateRoleRefname,
    ResourceFileDateRoleShortname,
    ResourceFileDateRefname,
    ResourceFileDateShortname,
    ResourceFileDescription,
    ResourceFileDescriptionRefname,
    ResourceFileDescriptionShortname,
    ResourceFileDetail,
    ResourceFileDetailRefname,
    ResourceFileDetailShortname,
    ResourceFileFeature,
    ResourceFileFeatureDescription,
    ResourceFileFeatureDescriptionRefname,
    ResourceFileFeatureDescriptionShortname,
    ResourceFileFeatureType,
    ResourceFileFeatureTypeRefname,
    ResourceFileFeatureTypeShortname,
    ResourceFileFeatureValue,
    ResourceFileFeatureValueRefname,
    ResourceFileFeatureValueShortname,
    ResourceFileFeatureRefname,
    ResourceFileFeatureShortname,
    ResourceFileLink,
    ResourceFileLinkRefname,
    ResourceFileLinkShortname,
    ResourceForm,
    ResourceFormRefname,
    ResourceFormShortname,
    ResourceIdtype,
    ResourceIdtypeRefname,
    ResourceIdtypeShortname,
    ResourceIdentifier,
    ResourceIdentifierRefname,
    ResourceIdentifierShortname,
    ResourceLink,
    ResourceLinkRefname,
    ResourceLinkShortname,
    ResourceMode,
    ResourceModeRefname,
    ResourceModeShortname,
    ResourceRole,
    ResourceRoleRefname,
    ResourceRoleShortname,
    ResourceVersion,
    ResourceVersionFeature,
    ResourceVersionFeatureType,
    ResourceVersionFeatureTypeRefname,
    ResourceVersionFeatureTypeShortname,
    ResourceVersionFeatureRefname,
    ResourceVersionFeatureShortname,
    ResourceVersionRefname,
    ResourceVersionShortname,
    ReturnsCode,
    ReturnsCodeType,
    ReturnsCodeTypeName,
    ReturnsCodeTypeNameRefname,
    ReturnsCodeTypeNameShortname,
    ReturnsCodeTypeRefname,
    ReturnsCodeTypeShortname,
    ReturnsCodeRefname,
    ReturnsCodeShortname,
    ReturnsConditions,
    ReturnsConditionsRefname,
    ReturnsConditionsShortname,
    ReturnsNote,
    ReturnsNoteRefname,
    ReturnsNoteShortname,
    ReviewRating,
    ReviewRatingRefname,
    ReviewRatingShortname,
    SalesOutlet,
    SalesOutletIdtype,
    SalesOutletIdtypeRefname,
    SalesOutletIdtypeShortname,
    SalesOutletIdentifier,
    SalesOutletIdentifierRefname,
    SalesOutletIdentifierShortname,
    SalesOutletName,
    SalesOutletNameRefname,
    SalesOutletNameShortname,
    SalesOutletRefname,
    SalesOutletShortname,
    SalesRestriction,
    SalesRestrictionNote,
    SalesRestrictionNoteRefname,
    SalesRestrictionNoteShortname,
    SalesRestrictionType,
    SalesRestrictionTypeRefname,
    SalesRestrictionTypeShortname,
    SalesRestrictionRefname,
    SalesRestrictionShortname,
    SalesRights,
    SalesRightsType,
    SalesRightsTypeRefname,
    SalesRightsTypeShortname,
    SalesRightsRefname,
    SalesRightsShortname,
    ScriptCode,
    ScriptCodeRefname,
    ScriptCodeShortname,
    Sender,
    SenderIdtype,
    SenderIdtypeRefname,
    SenderIdtypeShortname,
    SenderIdentifier,
    SenderIdentifierRefname,
    SenderIdentifierShortname,
    SenderName,
    SenderNameRefname,
    SenderNameShortname,
    SenderRefname,
    SenderShortname,
    SentDateTime,
    SentDateTimeRefname,
    SentDateTimeShortname,
    SequenceNumber,
    SequenceNumberRefname,
    SequenceNumberShortname,
    SourceName,
    SourceNameRefname,
    SourceNameShortname,
    SourceTitle,
    SourceTitleRefname,
    SourceTitleShortname,
    SourceType,
    SourceTypeRefname,
    SourceTypeShortname,
    SpecificationBundleName,
    SpecificationBundleNameTypeName,
    SpecificationBundleNameTypeNameRefname,
    SpecificationBundleNameTypeNameShortname,
    SpecificationBundleNameValue,
    SpecificationBundleNameValueRefname,
    SpecificationBundleNameValueShortname,
    SpecificationBundleNameRefname,
    SpecificationBundleNameShortname,
    SpecificationDescription,
    SpecificationDescriptionRefname,
    SpecificationDescriptionShortname,
    SpecificationDetail,
    SpecificationDetailRefname,
    SpecificationDetailShortname,
    SpecificationFeature,
    SpecificationFeatureDescription,
    SpecificationFeatureDescriptionRefname,
    SpecificationFeatureDescriptionShortname,
    SpecificationFeatureType,
    SpecificationFeatureTypeRefname,
    SpecificationFeatureTypeShortname,
    SpecificationFeatureValue,
    SpecificationFeatureValueRefname,
    SpecificationFeatureValueShortname,
    SpecificationFeatureRefname,
    SpecificationFeatureShortname,
    StartDate,
    StartDateRefname,
    StartDateShortname,
    StartTime,
    StartTimeRefname,
    StartTimeShortname,
    Stock,
    StockQuantityCode,
    StockQuantityCodeType,
    StockQuantityCodeTypeName,
    StockQuantityCodeTypeNameRefname,
    StockQuantityCodeTypeNameShortname,
    StockQuantityCodeTypeRefname,
    StockQuantityCodeTypeShortname,
    StockQuantityCodeRefname,
    StockQuantityCodeShortname,
    StockQuantityCoded,
    StockQuantityCodedRefname,
    StockQuantityCodedShortname,
    StockRefname,
    StockShortname,
    StreetAddress,
    StreetAddressRefname,
    StreetAddressShortname,
    StudyBibleType,
    StudyBibleTypeRefname,
    StudyBibleTypeShortname,
    Subject,
    SubjectCode,
    SubjectCodeRefname,
    SubjectCodeShortname,
    SubjectDate,
    SubjectDateRole,
    SubjectDateRoleRefname,
    SubjectDateRoleShortname,
    SubjectDateRefname,
    SubjectDateShortname,
    SubjectHeadingText,
    SubjectHeadingTextRefname,
    SubjectHeadingTextShortname,
    SubjectSchemeIdentifier,
    SubjectSchemeIdentifierRefname,
    SubjectSchemeIdentifierShortname,
    SubjectSchemeName,
    SubjectSchemeNameRefname,
    SubjectSchemeNameShortname,
    SubjectSchemeVersion,
    SubjectSchemeVersionRefname,
    SubjectSchemeVersionShortname,
    SubjectRefname,
    SubjectShortname,
    Subtitle,
    SubtitleRefname,
    SubtitleShortname,
    SuffixToKey,
    SuffixToKeyRefname,
    SuffixToKeyShortname,
    SupplementManifest,
    SupplementManifestRefname,
    SupplementManifestShortname,
    Supplier,
    SupplierCodeType,
    SupplierCodeTypeName,
    SupplierCodeTypeNameRefname,
    SupplierCodeTypeNameShortname,
    SupplierCodeTypeRefname,
    SupplierCodeTypeShortname,
    SupplierCodeValue,
    SupplierCodeValueRefname,
    SupplierCodeValueShortname,
    SupplierIdtype,
    SupplierIdtypeRefname,
    SupplierIdtypeShortname,
    SupplierIdentifier,
    SupplierIdentifierRefname,
    SupplierIdentifierShortname,
    SupplierName,
    SupplierNameRefname,
    SupplierNameShortname,
    SupplierOwnCoding,
    SupplierOwnCodingRefname,
    SupplierOwnCodingShortname,
    SupplierRole,
    SupplierRoleRefname,
    SupplierRoleShortname,
    SupplierRefname,
    SupplierShortname,
    SupplyContact,
    SupplyContactIdtype,
    SupplyContactIdtypeRefname,
    SupplyContactIdtypeShortname,
    SupplyContactIdentifier,
    SupplyContactIdentifierRefname,
    SupplyContactIdentifierShortname,
    SupplyContactName,
    SupplyContactNameRefname,
    SupplyContactNameShortname,
    SupplyContactRole,
    SupplyContactRoleRefname,
    SupplyContactRoleShortname,
    SupplyContactRefname,
    SupplyContactShortname,
    SupplyDate,
    SupplyDateRole,
    SupplyDateRoleRefname,
    SupplyDateRoleShortname,
    SupplyDateRefname,
    SupplyDateShortname,
    SupplyDetail,
    SupplyDetailRefname,
    SupplyDetailShortname,
    SupportingResource,
    SupportingResourceRefname,
    SupportingResourceShortname,
    Tax,
    TaxAmount,
    TaxAmountRefname,
    TaxAmountShortname,
    TaxExempt,
    TaxExemptRefname,
    TaxExemptShortname,
    TaxRateCode,
    TaxRateCodeRefname,
    TaxRateCodeShortname,
    TaxRatePercent,
    TaxRatePercentRefname,
    TaxRatePercentShortname,
    TaxType,
    TaxTypeRefname,
    TaxTypeShortname,
    TaxRefname,
    TaxShortname,
    TaxableAmount,
    TaxableAmountRefname,
    TaxableAmountShortname,
    TelephoneNumber,
    TelephoneNumberRefname,
    TelephoneNumberShortname,
    Territory,
    TerritoryRefname,
    TerritoryShortname,
    Text,
    TextAuthor,
    TextAuthorRefname,
    TextAuthorShortname,
    TextContent,
    TextContentRefname,
    TextContentShortname,
    TextItem,
    TextItemIdtype,
    TextItemIdtypeRefname,
    TextItemIdtypeShortname,
    TextItemIdentifier,
    TextItemIdentifierRefname,
    TextItemIdentifierShortname,
    TextItemType,
    TextItemTypeRefname,
    TextItemTypeShortname,
    TextItemRefname,
    TextItemShortname,
    TextSourceCorporate,
    TextSourceCorporateRefname,
    TextSourceCorporateShortname,
    TextSourceDescription,
    TextSourceDescriptionRefname,
    TextSourceDescriptionShortname,
    TextType,
    TextTypeRefname,
    TextTypeShortname,
    TextRefname,
    TextShortname,
    ThesisPresentedTo,
    ThesisPresentedToRefname,
    ThesisPresentedToShortname,
    ThesisType,
    ThesisTypeRefname,
    ThesisTypeShortname,
    ThesisYear,
    ThesisYearRefname,
    ThesisYearShortname,
    TimeRun,
    TimeRunRefname,
    TimeRunShortname,
    TitleDetail,
    TitleDetailRefname,
    TitleDetailShortname,
    TitleElement,
    TitleElementLevel,
    TitleElementLevelRefname,
    TitleElementLevelShortname,
    TitleElementRefname,
    TitleElementShortname,
    TitlePrefix,
    TitlePrefixRefname,
    TitlePrefixShortname,
    TitleStatement,
    TitleStatementRefname,
    TitleStatementShortname,
    TitleText,
    TitleTextRefname,
    TitleTextShortname,
    TitleType,
    TitleTypeRefname,
    TitleTypeShortname,
    TitleWithoutPrefix,
    TitleWithoutPrefixRefname,
    TitleWithoutPrefixShortname,
    TitlesAfterNames,
    TitlesAfterNamesRefname,
    TitlesAfterNamesShortname,
    TitlesBeforeNames,
    TitlesBeforeNamesRefname,
    TitlesBeforeNamesShortname,
    ToLanguage,
    ToLanguageRefname,
    ToLanguageShortname,
    ToQuantity,
    ToQuantityRefname,
    ToQuantityShortname,
    TradeCategory,
    TradeCategoryRefname,
    TradeCategoryShortname,
    UnnamedPersons,
    UnnamedPersonsRefname,
    UnnamedPersonsShortname,
    UnpricedItemType,
    UnpricedItemTypeRefname,
    UnpricedItemTypeShortname,
    Velocity,
    VelocityMetric,
    VelocityMetricRefname,
    VelocityMetricShortname,
    VelocityRefname,
    VelocityShortname,
    VenueName,
    VenueNameRefname,
    VenueNameShortname,
    VenueNote,
    VenueNoteRefname,
    VenueNoteShortname,
    Website,
    WebsiteDescription,
    WebsiteDescriptionRefname,
    WebsiteDescriptionShortname,
    WebsiteLink,
    WebsiteLinkRefname,
    WebsiteLinkShortname,
    WebsiteRole,
    WebsiteRoleRefname,
    WebsiteRoleShortname,
    WebsiteRefname,
    WebsiteShortname,
    WorkIdtype,
    WorkIdtypeRefname,
    WorkIdtypeShortname,
    WorkIdentifier,
    WorkIdentifierRefname,
    WorkIdentifierShortname,
    WorkRelationCode,
    WorkRelationCodeRefname,
    WorkRelationCodeShortname,
    YearOfAnnual,
    YearOfAnnualRefname,
    YearOfAnnualShortname,
    ReleaseAttributeRelease,
)
from onix.book.v3_0.reference.onix_book_product_code_lists import (
    List1,
    List100,
    List102,
    List12,
    List121,
    List13,
    List14,
    List141,
    List142,
    List144,
    List145,
    List146,
    List147,
    List148,
    List149,
    List15,
    List150,
    List151,
    List152,
    List153,
    List154,
    List155,
    List156,
    List157,
    List158,
    List159,
    List16,
    List160,
    List161,
    List162,
    List163,
    List164,
    List165,
    List166,
    List167,
    List168,
    List169,
    List17,
    List170,
    List171,
    List172,
    List173,
    List174,
    List175,
    List177,
    List179,
    List18,
    List19,
    List197,
    List198,
    List2,
    List20,
    List21,
    List215,
    List216,
    List217,
    List218,
    List219,
    List22,
    List228,
    List229,
    List23,
    List230,
    List239,
    List24,
    List240,
    List241,
    List244,
    List245,
    List246,
    List247,
    List248,
    List249,
    List25,
    List250,
    List252,
    List253,
    List254,
    List255,
    List27,
    List28,
    List29,
    List3,
    List30,
    List31,
    List32,
    List34,
    List41,
    List42,
    List43,
    List44,
    List45,
    List46,
    List48,
    List49,
    List5,
    List50,
    List51,
    List53,
    List55,
    List57,
    List58,
    List59,
    List60,
    List61,
    List62,
    List64,
    List65,
    List68,
    List69,
    List70,
    List71,
    List72,
    List73,
    List74,
    List79,
    List80,
    List81,
    List82,
    List83,
    List84,
    List85,
    List86,
    List87,
    List89,
    List9,
    List90,
    List91,
    List92,
    List93,
    List96,
    List97,
)
from onix.book.v3_0.reference.onix_xhtml_subset import (
    Block,
    Flow,
    Inline,
    Scope,
    Shape,
    Tframe,
    Trules,
    A,
    AContent,
    Abbr,
    Acronym,
    Address,
    Area,
    AreaAttlistNohref,
    B,
    Bdo,
    BdoAttlistDir,
    Big,
    Blockquote,
    Br,
    Caption,
    CellhalignAlign,
    CellvalignValign,
    Cite,
    Code,
    Col,
    Colgroup,
    Dd,
    Dfn,
    Div,
    Dl,
    Dt,
    Em,
    H1,
    H2,
    H3,
    H4,
    H5,
    H6,
    Hr,
    I,
    I18NDir,
    Img,
    ImgAttlistIsmap,
    Kbd,
    Li,
    Map,
    Ol,
    P,
    Pre,
    PreContent,
    Q,
    Rb,
    Rbc,
    Rp,
    Rt,
    Rtc,
    Ruby,
    RubyContent,
    Samp,
    Small,
    Span,
    Strong,
    Sub,
    Sup,
    Table,
    Tbody,
    Td,
    Tfoot,
    Th,
    Thead,
    Tr,
    Tt,
    Ul,
    Var,
)

__all__ = [
    "Avduration",
    "AvdurationRefname",
    "AvdurationShortname",
    "Avitem",
    "AvitemIdtype",
    "AvitemIdtypeRefname",
    "AvitemIdtypeShortname",
    "AvitemIdentifier",
    "AvitemIdentifierRefname",
    "AvitemIdentifierShortname",
    "AvitemType",
    "AvitemTypeRefname",
    "AvitemTypeShortname",
    "AvitemRefname",
    "AvitemShortname",
    "Addressee",
    "AddresseeIdtype",
    "AddresseeIdtypeRefname",
    "AddresseeIdtypeShortname",
    "AddresseeIdentifier",
    "AddresseeIdentifierRefname",
    "AddresseeIdentifierShortname",
    "AddresseeName",
    "AddresseeNameRefname",
    "AddresseeNameShortname",
    "AddresseeRefname",
    "AddresseeShortname",
    "Affiliation",
    "AffiliationRefname",
    "AffiliationShortname",
    "AgentIdtype",
    "AgentIdtypeRefname",
    "AgentIdtypeShortname",
    "AgentIdentifier",
    "AgentIdentifierRefname",
    "AgentIdentifierShortname",
    "AgentName",
    "AgentNameRefname",
    "AgentNameShortname",
    "AgentRole",
    "AgentRoleRefname",
    "AgentRoleShortname",
    "AlternativeName",
    "AlternativeNameRefname",
    "AlternativeNameShortname",
    "AncillaryContent",
    "AncillaryContentDescription",
    "AncillaryContentDescriptionRefname",
    "AncillaryContentDescriptionShortname",
    "AncillaryContentType",
    "AncillaryContentTypeRefname",
    "AncillaryContentTypeShortname",
    "AncillaryContentRefname",
    "AncillaryContentShortname",
    "Audience",
    "AudienceCode",
    "AudienceCodeType",
    "AudienceCodeTypeName",
    "AudienceCodeTypeNameRefname",
    "AudienceCodeTypeNameShortname",
    "AudienceCodeTypeRefname",
    "AudienceCodeTypeShortname",
    "AudienceCodeValue",
    "AudienceCodeValueRefname",
    "AudienceCodeValueShortname",
    "AudienceCodeRefname",
    "AudienceCodeShortname",
    "AudienceDescription",
    "AudienceDescriptionRefname",
    "AudienceDescriptionShortname",
    "AudienceHeadingText",
    "AudienceHeadingTextRefname",
    "AudienceHeadingTextShortname",
    "AudienceRange",
    "AudienceRangePrecision",
    "AudienceRangePrecisionRefname",
    "AudienceRangePrecisionShortname",
    "AudienceRangeQualifier",
    "AudienceRangeQualifierRefname",
    "AudienceRangeQualifierShortname",
    "AudienceRangeValue",
    "AudienceRangeValueRefname",
    "AudienceRangeValueShortname",
    "AudienceRangeRefname",
    "AudienceRangeShortname",
    "AudienceRefname",
    "AudienceShortname",
    "Barcode",
    "BarcodeType",
    "BarcodeTypeRefname",
    "BarcodeTypeShortname",
    "BarcodeRefname",
    "BarcodeShortname",
    "BatchBonus",
    "BatchBonusRefname",
    "BatchBonusShortname",
    "BatchQuantity",
    "BatchQuantityRefname",
    "BatchQuantityShortname",
    "Bible",
    "BibleContents",
    "BibleContentsRefname",
    "BibleContentsShortname",
    "BiblePurpose",
    "BiblePurposeRefname",
    "BiblePurposeShortname",
    "BibleReferenceLocation",
    "BibleReferenceLocationRefname",
    "BibleReferenceLocationShortname",
    "BibleTextFeature",
    "BibleTextFeatureRefname",
    "BibleTextFeatureShortname",
    "BibleTextOrganization",
    "BibleTextOrganizationRefname",
    "BibleTextOrganizationShortname",
    "BibleVersion",
    "BibleVersionRefname",
    "BibleVersionShortname",
    "BibleRefname",
    "BibleShortname",
    "BiographicalNote",
    "BiographicalNoteRefname",
    "BiographicalNoteShortname",
    "BodyManifest",
    "BodyManifestRefname",
    "BodyManifestShortname",
    "BodyResource",
    "BodyResourceRefname",
    "BodyResourceShortname",
    "BookClubAdoption",
    "BookClubAdoptionRefname",
    "BookClubAdoptionShortname",
    "Cbo",
    "CboRefname",
    "CboShortname",
    "CitationNote",
    "CitationNoteRefname",
    "CitationNoteShortname",
    "CitedContent",
    "CitedContentType",
    "CitedContentTypeRefname",
    "CitedContentTypeShortname",
    "CitedContentRefname",
    "CitedContentShortname",
    "CityOfPublication",
    "CityOfPublicationRefname",
    "CityOfPublicationShortname",
    "CollateralDetail",
    "CollateralDetailRefname",
    "CollateralDetailShortname",
    "Collection",
    "CollectionIdtype",
    "CollectionIdtypeRefname",
    "CollectionIdtypeShortname",
    "CollectionIdentifier",
    "CollectionIdentifierRefname",
    "CollectionIdentifierShortname",
    "CollectionSequence",
    "CollectionSequenceNumber",
    "CollectionSequenceNumberRefname",
    "CollectionSequenceNumberShortname",
    "CollectionSequenceType",
    "CollectionSequenceTypeName",
    "CollectionSequenceTypeNameRefname",
    "CollectionSequenceTypeNameShortname",
    "CollectionSequenceTypeRefname",
    "CollectionSequenceTypeShortname",
    "CollectionSequenceRefname",
    "CollectionSequenceShortname",
    "CollectionType",
    "CollectionTypeRefname",
    "CollectionTypeShortname",
    "CollectionRefname",
    "CollectionShortname",
    "ComparisonProductPrice",
    "ComparisonProductPriceRefname",
    "ComparisonProductPriceShortname",
    "Complexity",
    "ComplexityCode",
    "ComplexityCodeRefname",
    "ComplexityCodeShortname",
    "ComplexitySchemeIdentifier",
    "ComplexitySchemeIdentifierRefname",
    "ComplexitySchemeIdentifierShortname",
    "ComplexityRefname",
    "ComplexityShortname",
    "ComponentNumber",
    "ComponentNumberRefname",
    "ComponentNumberShortname",
    "ComponentTypeName",
    "ComponentTypeNameRefname",
    "ComponentTypeNameShortname",
    "Conference",
    "ConferenceAcronym",
    "ConferenceAcronymRefname",
    "ConferenceAcronymShortname",
    "ConferenceDate",
    "ConferenceDateRefname",
    "ConferenceDateShortname",
    "ConferenceName",
    "ConferenceNameRefname",
    "ConferenceNameShortname",
    "ConferenceNumber",
    "ConferenceNumberRefname",
    "ConferenceNumberShortname",
    "ConferencePlace",
    "ConferencePlaceRefname",
    "ConferencePlaceShortname",
    "ConferenceRole",
    "ConferenceRoleRefname",
    "ConferenceRoleShortname",
    "ConferenceSponsor",
    "ConferenceSponsorIdtype",
    "ConferenceSponsorIdtypeRefname",
    "ConferenceSponsorIdtypeShortname",
    "ConferenceSponsorIdentifier",
    "ConferenceSponsorIdentifierRefname",
    "ConferenceSponsorIdentifierShortname",
    "ConferenceSponsorRefname",
    "ConferenceSponsorShortname",
    "ConferenceTheme",
    "ConferenceThemeRefname",
    "ConferenceThemeShortname",
    "ConferenceRefname",
    "ConferenceShortname",
    "ContactName",
    "ContactNameRefname",
    "ContactNameShortname",
    "ContentAudience",
    "ContentAudienceRefname",
    "ContentAudienceShortname",
    "ContentDate",
    "ContentDateRole",
    "ContentDateRoleRefname",
    "ContentDateRoleShortname",
    "ContentDateRefname",
    "ContentDateShortname",
    "ContentDetail",
    "ContentDetailRefname",
    "ContentDetailShortname",
    "ContentItem",
    "ContentItemRefname",
    "ContentItemShortname",
    "Contributor",
    "ContributorDate",
    "ContributorDateRole",
    "ContributorDateRoleRefname",
    "ContributorDateRoleShortname",
    "ContributorDateRefname",
    "ContributorDateShortname",
    "ContributorDescription",
    "ContributorDescriptionRefname",
    "ContributorDescriptionShortname",
    "ContributorPlace",
    "ContributorPlaceRelator",
    "ContributorPlaceRelatorRefname",
    "ContributorPlaceRelatorShortname",
    "ContributorPlaceRefname",
    "ContributorPlaceShortname",
    "ContributorReference",
    "ContributorReferenceRefname",
    "ContributorReferenceShortname",
    "ContributorRole",
    "ContributorRoleRefname",
    "ContributorRoleShortname",
    "ContributorStatement",
    "ContributorStatementRefname",
    "ContributorStatementShortname",
    "ContributorRefname",
    "ContributorShortname",
    "CopiesSold",
    "CopiesSoldRefname",
    "CopiesSoldShortname",
    "CopyrightOwner",
    "CopyrightOwnerIdtype",
    "CopyrightOwnerIdtypeRefname",
    "CopyrightOwnerIdtypeShortname",
    "CopyrightOwnerIdentifier",
    "CopyrightOwnerIdentifierRefname",
    "CopyrightOwnerIdentifierShortname",
    "CopyrightOwnerRefname",
    "CopyrightOwnerShortname",
    "CopyrightStatement",
    "CopyrightStatementRefname",
    "CopyrightStatementShortname",
    "CopyrightType",
    "CopyrightTypeRefname",
    "CopyrightTypeShortname",
    "CopyrightYear",
    "CopyrightYearRefname",
    "CopyrightYearShortname",
    "CorporateName",
    "CorporateNameInverted",
    "CorporateNameInvertedRefname",
    "CorporateNameInvertedShortname",
    "CorporateNameRefname",
    "CorporateNameShortname",
    "CountriesExcluded",
    "CountriesExcludedRefname",
    "CountriesExcludedShortname",
    "CountriesIncluded",
    "CountriesIncludedRefname",
    "CountriesIncludedShortname",
    "CountryCode",
    "CountryCodeRefname",
    "CountryCodeShortname",
    "CountryOfManufacture",
    "CountryOfManufactureRefname",
    "CountryOfManufactureShortname",
    "CountryOfPublication",
    "CountryOfPublicationRefname",
    "CountryOfPublicationShortname",
    "CoverManifest",
    "CoverManifestRefname",
    "CoverManifestShortname",
    "CoverResource",
    "CoverResourceRefname",
    "CoverResourceShortname",
    "CurrencyCode",
    "CurrencyCodeRefname",
    "CurrencyCodeShortname",
    "CurrencyZone",
    "CurrencyZoneRefname",
    "CurrencyZoneShortname",
    "Date",
    "DateFormat",
    "DateFormatRefname",
    "DateFormatShortname",
    "DateRefname",
    "DateShortname",
    "DefaultCurrencyCode",
    "DefaultCurrencyCodeRefname",
    "DefaultCurrencyCodeShortname",
    "DefaultLanguageOfText",
    "DefaultLanguageOfTextRefname",
    "DefaultLanguageOfTextShortname",
    "DefaultPriceType",
    "DefaultPriceTypeRefname",
    "DefaultPriceTypeShortname",
    "DeletionText",
    "DeletionTextRefname",
    "DeletionTextShortname",
    "DescriptiveDetail",
    "DescriptiveDetailRefname",
    "DescriptiveDetailShortname",
    "Discount",
    "DiscountAmount",
    "DiscountAmountRefname",
    "DiscountAmountShortname",
    "DiscountCode",
    "DiscountCodeType",
    "DiscountCodeTypeName",
    "DiscountCodeTypeNameRefname",
    "DiscountCodeTypeNameShortname",
    "DiscountCodeTypeRefname",
    "DiscountCodeTypeShortname",
    "DiscountCodeRefname",
    "DiscountCodeShortname",
    "DiscountCoded",
    "DiscountCodedRefname",
    "DiscountCodedShortname",
    "DiscountPercent",
    "DiscountPercentRefname",
    "DiscountPercentShortname",
    "DiscountType",
    "DiscountTypeRefname",
    "DiscountTypeShortname",
    "DiscountRefname",
    "DiscountShortname",
    "EditionNumber",
    "EditionNumberRefname",
    "EditionNumberShortname",
    "EditionStatement",
    "EditionStatementRefname",
    "EditionStatementShortname",
    "EditionType",
    "EditionTypeRefname",
    "EditionTypeShortname",
    "EditionVersionNumber",
    "EditionVersionNumberRefname",
    "EditionVersionNumberShortname",
    "EmailAddress",
    "EmailAddressRefname",
    "EmailAddressShortname",
    "EndDate",
    "EndDateRefname",
    "EndDateShortname",
    "EndTime",
    "EndTimeRefname",
    "EndTimeShortname",
    "EpubLicense",
    "EpubLicenseExpression",
    "EpubLicenseExpressionLink",
    "EpubLicenseExpressionLinkRefname",
    "EpubLicenseExpressionLinkShortname",
    "EpubLicenseExpressionType",
    "EpubLicenseExpressionTypeName",
    "EpubLicenseExpressionTypeNameRefname",
    "EpubLicenseExpressionTypeNameShortname",
    "EpubLicenseExpressionTypeRefname",
    "EpubLicenseExpressionTypeShortname",
    "EpubLicenseExpressionRefname",
    "EpubLicenseExpressionShortname",
    "EpubLicenseName",
    "EpubLicenseNameRefname",
    "EpubLicenseNameShortname",
    "EpubLicenseRefname",
    "EpubLicenseShortname",
    "EpubTechnicalProtection",
    "EpubTechnicalProtectionRefname",
    "EpubTechnicalProtectionShortname",
    "EpubUsageConstraint",
    "EpubUsageConstraintRefname",
    "EpubUsageConstraintShortname",
    "EpubUsageLimit",
    "EpubUsageLimitRefname",
    "EpubUsageLimitShortname",
    "EpubUsageStatus",
    "EpubUsageStatusRefname",
    "EpubUsageStatusShortname",
    "EpubUsageType",
    "EpubUsageTypeRefname",
    "EpubUsageTypeShortname",
    "EpubUsageUnit",
    "EpubUsageUnitRefname",
    "EpubUsageUnitShortname",
    "Event",
    "EventAcronym",
    "EventAcronymRefname",
    "EventAcronymShortname",
    "EventDate",
    "EventDateRefname",
    "EventDateShortname",
    "EventDescription",
    "EventDescriptionRefname",
    "EventDescriptionShortname",
    "EventIdtype",
    "EventIdtypeRefname",
    "EventIdtypeShortname",
    "EventIdentifier",
    "EventIdentifierRefname",
    "EventIdentifierShortname",
    "EventName",
    "EventNameRefname",
    "EventNameShortname",
    "EventNumber",
    "EventNumberRefname",
    "EventNumberShortname",
    "EventOccurrence",
    "EventOccurrenceRefname",
    "EventOccurrenceShortname",
    "EventPlace",
    "EventPlaceRefname",
    "EventPlaceShortname",
    "EventRole",
    "EventRoleRefname",
    "EventRoleShortname",
    "EventSponsor",
    "EventSponsorIdtype",
    "EventSponsorIdtypeRefname",
    "EventSponsorIdtypeShortname",
    "EventSponsorIdentifier",
    "EventSponsorIdentifierRefname",
    "EventSponsorIdentifierShortname",
    "EventSponsorRefname",
    "EventSponsorShortname",
    "EventStatus",
    "EventStatusRefname",
    "EventStatusShortname",
    "EventTheme",
    "EventThemeRefname",
    "EventThemeShortname",
    "EventType",
    "EventTypeRefname",
    "EventTypeShortname",
    "EventRefname",
    "EventShortname",
    "ExpectedDate",
    "ExpectedDateRefname",
    "ExpectedDateShortname",
    "Extent",
    "ExtentType",
    "ExtentTypeRefname",
    "ExtentTypeShortname",
    "ExtentUnit",
    "ExtentUnitRefname",
    "ExtentUnitShortname",
    "ExtentValue",
    "ExtentValueRoman",
    "ExtentValueRomanRefname",
    "ExtentValueRomanShortname",
    "ExtentValueRefname",
    "ExtentValueShortname",
    "ExtentRefname",
    "ExtentShortname",
    "FaxNumber",
    "FaxNumberRefname",
    "FaxNumberShortname",
    "FeatureNote",
    "FeatureNoteRefname",
    "FeatureNoteShortname",
    "FeatureValue",
    "FeatureValueRefname",
    "FeatureValueShortname",
    "FirstPageNumber",
    "FirstPageNumberRefname",
    "FirstPageNumberShortname",
    "FreeQuantity",
    "FreeQuantityRefname",
    "FreeQuantityShortname",
    "FromLanguage",
    "FromLanguageRefname",
    "FromLanguageShortname",
    "Funding",
    "FundingIdtype",
    "FundingIdtypeRefname",
    "FundingIdtypeShortname",
    "FundingIdentifier",
    "FundingIdentifierRefname",
    "FundingIdentifierShortname",
    "FundingRefname",
    "FundingShortname",
    "Gender",
    "GenderRefname",
    "GenderShortname",
    "Header",
    "HeaderRefname",
    "HeaderShortname",
    "IdtypeName",
    "IdtypeNameRefname",
    "IdtypeNameShortname",
    "Idvalue",
    "IdvalueRefname",
    "IdvalueShortname",
    "Illustrated",
    "IllustratedRefname",
    "IllustratedShortname",
    "IllustrationsNote",
    "IllustrationsNoteRefname",
    "IllustrationsNoteShortname",
    "Imprint",
    "ImprintIdtype",
    "ImprintIdtypeRefname",
    "ImprintIdtypeShortname",
    "ImprintIdentifier",
    "ImprintIdentifierRefname",
    "ImprintIdentifierShortname",
    "ImprintName",
    "ImprintNameRefname",
    "ImprintNameShortname",
    "ImprintRefname",
    "ImprintShortname",
    "InitialPrintRun",
    "InitialPrintRunRefname",
    "InitialPrintRunShortname",
    "InsertManifest",
    "InsertManifestRefname",
    "InsertManifestShortname",
    "InsertPoint",
    "InsertPointType",
    "InsertPointTypeRefname",
    "InsertPointTypeShortname",
    "InsertPointValue",
    "InsertPointValueRefname",
    "InsertPointValueShortname",
    "InsertPointRefname",
    "InsertPointShortname",
    "InsertResource",
    "InsertResourceRefname",
    "InsertResourceShortname",
    "KeyNames",
    "KeyNamesRefname",
    "KeyNamesShortname",
    "Language",
    "LanguageCode",
    "LanguageCodeRefname",
    "LanguageCodeShortname",
    "LanguageRole",
    "LanguageRoleRefname",
    "LanguageRoleShortname",
    "LanguageRefname",
    "LanguageShortname",
    "LastPageNumber",
    "LastPageNumberRefname",
    "LastPageNumberShortname",
    "LatestReprintNumber",
    "LatestReprintNumberRefname",
    "LatestReprintNumberShortname",
    "LettersAfterNames",
    "LettersAfterNamesRefname",
    "LettersAfterNamesShortname",
    "LevelSequenceNumber",
    "LevelSequenceNumberRefname",
    "LevelSequenceNumberShortname",
    "ListName",
    "ListNameRefname",
    "ListNameShortname",
    "LocationIdtype",
    "LocationIdtypeRefname",
    "LocationIdtypeShortname",
    "LocationIdentifier",
    "LocationIdentifierRefname",
    "LocationIdentifierShortname",
    "LocationName",
    "LocationNameRefname",
    "LocationNameShortname",
    "MainSubject",
    "MainSubjectRefname",
    "MainSubjectShortname",
    "MapScale",
    "MapScaleRefname",
    "MapScaleShortname",
    "Market",
    "MarketDate",
    "MarketDateRole",
    "MarketDateRoleRefname",
    "MarketDateRoleShortname",
    "MarketDateRefname",
    "MarketDateShortname",
    "MarketPublishingDetail",
    "MarketPublishingDetailRefname",
    "MarketPublishingDetailShortname",
    "MarketPublishingStatus",
    "MarketPublishingStatusNote",
    "MarketPublishingStatusNoteRefname",
    "MarketPublishingStatusNoteShortname",
    "MarketPublishingStatusRefname",
    "MarketPublishingStatusShortname",
    "MarketRefname",
    "MarketShortname",
    "Measure",
    "MeasureType",
    "MeasureTypeRefname",
    "MeasureTypeShortname",
    "MeasureUnitCode",
    "MeasureUnitCodeRefname",
    "MeasureUnitCodeShortname",
    "MeasureRefname",
    "MeasureShortname",
    "Measurement",
    "MeasurementRefname",
    "MeasurementShortname",
    "MessageNote",
    "MessageNoteRefname",
    "MessageNoteShortname",
    "MessageNumber",
    "MessageNumberRefname",
    "MessageNumberShortname",
    "MessageRepeat",
    "MessageRepeatRefname",
    "MessageRepeatShortname",
    "MinimumOrderQuantity",
    "MinimumOrderQuantityRefname",
    "MinimumOrderQuantityShortname",
    "NameAsSubject",
    "NameAsSubjectRefname",
    "NameAsSubjectShortname",
    "NameIdtype",
    "NameIdtypeRefname",
    "NameIdtypeShortname",
    "NameIdentifier",
    "NameIdentifierRefname",
    "NameIdentifierShortname",
    "NameType",
    "NameTypeRefname",
    "NameTypeShortname",
    "NamesAfterKey",
    "NamesAfterKeyRefname",
    "NamesAfterKeyShortname",
    "NamesBeforeKey",
    "NamesBeforeKeyRefname",
    "NamesBeforeKeyShortname",
    "NewSupplier",
    "NewSupplierRefname",
    "NewSupplierShortname",
    "NoCollection",
    "NoCollectionRefname",
    "NoCollectionShortname",
    "NoContributor",
    "NoContributorRefname",
    "NoContributorShortname",
    "NoEdition",
    "NoEditionRefname",
    "NoEditionShortname",
    "NoPrefix",
    "NoPrefixRefname",
    "NoPrefixShortname",
    "NoProduct",
    "NoProductRefname",
    "NoProductShortname",
    "NoResource",
    "NoResourceRefname",
    "NoResourceShortname",
    "NoSupplement",
    "NoSupplementRefname",
    "NoSupplementShortname",
    "NotificationType",
    "NotificationTypeRefname",
    "NotificationTypeShortname",
    "Number",
    "NumberOfCopies",
    "NumberOfCopiesRefname",
    "NumberOfCopiesShortname",
    "NumberOfIllustrations",
    "NumberOfIllustrationsRefname",
    "NumberOfIllustrationsShortname",
    "NumberOfItemsOfThisForm",
    "NumberOfItemsOfThisFormRefname",
    "NumberOfItemsOfThisFormShortname",
    "NumberOfPages",
    "NumberOfPagesRefname",
    "NumberOfPagesShortname",
    "NumberRefname",
    "NumberShortname",
    "Onixmessage",
    "OnixmessageRefname",
    "OnixmessageShortname",
    "OccurrenceDate",
    "OccurrenceDateRole",
    "OccurrenceDateRoleRefname",
    "OccurrenceDateRoleShortname",
    "OccurrenceDateRefname",
    "OccurrenceDateShortname",
    "OnHand",
    "OnHandRefname",
    "OnHandShortname",
    "OnOrder",
    "OnOrderDetail",
    "OnOrderDetailRefname",
    "OnOrderDetailShortname",
    "OnOrderRefname",
    "OnOrderShortname",
    "OrderQuantityMinimum",
    "OrderQuantityMinimumRefname",
    "OrderQuantityMinimumShortname",
    "OrderQuantityMultiple",
    "OrderQuantityMultipleRefname",
    "OrderQuantityMultipleShortname",
    "OrderTime",
    "OrderTimeRefname",
    "OrderTimeShortname",
    "PackQuantity",
    "PackQuantityRefname",
    "PackQuantityShortname",
    "PageRun",
    "PageRunRefname",
    "PageRunShortname",
    "PalletQuantity",
    "PalletQuantityRefname",
    "PalletQuantityShortname",
    "PartNumber",
    "PartNumberRefname",
    "PartNumberShortname",
    "Percent",
    "PercentRefname",
    "PercentShortname",
    "PersonName",
    "PersonNameInverted",
    "PersonNameInvertedRefname",
    "PersonNameInvertedShortname",
    "PersonNameRefname",
    "PersonNameShortname",
    "PositionOnList",
    "PositionOnListRefname",
    "PositionOnListShortname",
    "PositionOnProduct",
    "PositionOnProductRefname",
    "PositionOnProductShortname",
    "PrefixToKey",
    "PrefixToKeyRefname",
    "PrefixToKeyShortname",
    "Price",
    "PriceAmount",
    "PriceAmountRefname",
    "PriceAmountShortname",
    "PriceCode",
    "PriceCodeType",
    "PriceCodeTypeName",
    "PriceCodeTypeNameRefname",
    "PriceCodeTypeNameShortname",
    "PriceCodeTypeRefname",
    "PriceCodeTypeShortname",
    "PriceCodeRefname",
    "PriceCodeShortname",
    "PriceCoded",
    "PriceCodedRefname",
    "PriceCodedShortname",
    "PriceCondition",
    "PriceConditionQuantity",
    "PriceConditionQuantityType",
    "PriceConditionQuantityTypeRefname",
    "PriceConditionQuantityTypeShortname",
    "PriceConditionQuantityRefname",
    "PriceConditionQuantityShortname",
    "PriceConditionType",
    "PriceConditionTypeRefname",
    "PriceConditionTypeShortname",
    "PriceConditionRefname",
    "PriceConditionShortname",
    "PriceConstraint",
    "PriceConstraintLimit",
    "PriceConstraintLimitRefname",
    "PriceConstraintLimitShortname",
    "PriceConstraintStatus",
    "PriceConstraintStatusRefname",
    "PriceConstraintStatusShortname",
    "PriceConstraintType",
    "PriceConstraintTypeRefname",
    "PriceConstraintTypeShortname",
    "PriceConstraintUnit",
    "PriceConstraintUnitRefname",
    "PriceConstraintUnitShortname",
    "PriceConstraintRefname",
    "PriceConstraintShortname",
    "PriceDate",
    "PriceDateRole",
    "PriceDateRoleRefname",
    "PriceDateRoleShortname",
    "PriceDateRefname",
    "PriceDateShortname",
    "PriceIdtype",
    "PriceIdtypeRefname",
    "PriceIdtypeShortname",
    "PriceIdentifier",
    "PriceIdentifierRefname",
    "PriceIdentifierShortname",
    "PricePartDescription",
    "PricePartDescriptionRefname",
    "PricePartDescriptionShortname",
    "PricePer",
    "PricePerRefname",
    "PricePerShortname",
    "PriceQualifier",
    "PriceQualifierRefname",
    "PriceQualifierShortname",
    "PriceStatus",
    "PriceStatusRefname",
    "PriceStatusShortname",
    "PriceType",
    "PriceTypeDescription",
    "PriceTypeDescriptionRefname",
    "PriceTypeDescriptionShortname",
    "PriceTypeRefname",
    "PriceTypeShortname",
    "PriceRefname",
    "PriceShortname",
    "PrimaryContentType",
    "PrimaryContentTypeRefname",
    "PrimaryContentTypeShortname",
    "PrimaryPart",
    "PrimaryPartRefname",
    "PrimaryPartShortname",
    "PrintedOnProduct",
    "PrintedOnProductRefname",
    "PrintedOnProductShortname",
    "Prize",
    "PrizeCode",
    "PrizeCodeRefname",
    "PrizeCodeShortname",
    "PrizeCountry",
    "PrizeCountryRefname",
    "PrizeCountryShortname",
    "PrizeJury",
    "PrizeJuryRefname",
    "PrizeJuryShortname",
    "PrizeName",
    "PrizeNameRefname",
    "PrizeNameShortname",
    "PrizeRegion",
    "PrizeRegionRefname",
    "PrizeRegionShortname",
    "PrizeStatement",
    "PrizeStatementRefname",
    "PrizeStatementShortname",
    "PrizeYear",
    "PrizeYearRefname",
    "PrizeYearShortname",
    "PrizeRefname",
    "PrizeShortname",
    "Product",
    "ProductAvailability",
    "ProductAvailabilityRefname",
    "ProductAvailabilityShortname",
    "ProductClassification",
    "ProductClassificationCode",
    "ProductClassificationCodeRefname",
    "ProductClassificationCodeShortname",
    "ProductClassificationType",
    "ProductClassificationTypeName",
    "ProductClassificationTypeNameRefname",
    "ProductClassificationTypeNameShortname",
    "ProductClassificationTypeRefname",
    "ProductClassificationTypeShortname",
    "ProductClassificationRefname",
    "ProductClassificationShortname",
    "ProductComposition",
    "ProductCompositionRefname",
    "ProductCompositionShortname",
    "ProductContact",
    "ProductContactIdtype",
    "ProductContactIdtypeRefname",
    "ProductContactIdtypeShortname",
    "ProductContactIdentifier",
    "ProductContactIdentifierRefname",
    "ProductContactIdentifierShortname",
    "ProductContactName",
    "ProductContactNameRefname",
    "ProductContactNameShortname",
    "ProductContactRole",
    "ProductContactRoleRefname",
    "ProductContactRoleShortname",
    "ProductContactRefname",
    "ProductContactShortname",
    "ProductContentType",
    "ProductContentTypeRefname",
    "ProductContentTypeShortname",
    "ProductForm",
    "ProductFormDescription",
    "ProductFormDescriptionRefname",
    "ProductFormDescriptionShortname",
    "ProductFormDetail",
    "ProductFormDetailRefname",
    "ProductFormDetailShortname",
    "ProductFormFeature",
    "ProductFormFeatureDescription",
    "ProductFormFeatureDescriptionRefname",
    "ProductFormFeatureDescriptionShortname",
    "ProductFormFeatureType",
    "ProductFormFeatureTypeRefname",
    "ProductFormFeatureTypeShortname",
    "ProductFormFeatureValue",
    "ProductFormFeatureValueRefname",
    "ProductFormFeatureValueShortname",
    "ProductFormFeatureRefname",
    "ProductFormFeatureShortname",
    "ProductFormRefname",
    "ProductFormShortname",
    "ProductIdtype",
    "ProductIdtypeRefname",
    "ProductIdtypeShortname",
    "ProductIdentifier",
    "ProductIdentifierRefname",
    "ProductIdentifierShortname",
    "ProductPackaging",
    "ProductPackagingRefname",
    "ProductPackagingShortname",
    "ProductPart",
    "ProductPartRefname",
    "ProductPartShortname",
    "ProductRelationCode",
    "ProductRelationCodeRefname",
    "ProductRelationCodeShortname",
    "ProductSupply",
    "ProductSupplyRefname",
    "ProductSupplyShortname",
    "ProductRefname",
    "ProductShortname",
    "ProductionDetail",
    "ProductionDetailRefname",
    "ProductionDetailShortname",
    "ProductionManifest",
    "ProductionManifestRefname",
    "ProductionManifestShortname",
    "ProfessionalAffiliation",
    "ProfessionalAffiliationRefname",
    "ProfessionalAffiliationShortname",
    "ProfessionalPosition",
    "ProfessionalPositionRefname",
    "ProfessionalPositionShortname",
    "PromotionCampaign",
    "PromotionCampaignRefname",
    "PromotionCampaignShortname",
    "PromotionContact",
    "PromotionContactRefname",
    "PromotionContactShortname",
    "PromotionDetail",
    "PromotionDetailRefname",
    "PromotionDetailShortname",
    "PromotionalEvent",
    "PromotionalEventRefname",
    "PromotionalEventShortname",
    "Proximity",
    "ProximityRefname",
    "ProximityShortname",
    "Publisher",
    "PublisherIdtype",
    "PublisherIdtypeRefname",
    "PublisherIdtypeShortname",
    "PublisherIdentifier",
    "PublisherIdentifierRefname",
    "PublisherIdentifierShortname",
    "PublisherName",
    "PublisherNameRefname",
    "PublisherNameShortname",
    "PublisherRepresentative",
    "PublisherRepresentativeRefname",
    "PublisherRepresentativeShortname",
    "PublisherRefname",
    "PublisherShortname",
    "PublishingDate",
    "PublishingDateRole",
    "PublishingDateRoleRefname",
    "PublishingDateRoleShortname",
    "PublishingDateRefname",
    "PublishingDateShortname",
    "PublishingDetail",
    "PublishingDetailRefname",
    "PublishingDetailShortname",
    "PublishingRole",
    "PublishingRoleRefname",
    "PublishingRoleShortname",
    "PublishingStatus",
    "PublishingStatusNote",
    "PublishingStatusNoteRefname",
    "PublishingStatusNoteShortname",
    "PublishingStatusRefname",
    "PublishingStatusShortname",
    "Quantity",
    "QuantityUnit",
    "QuantityUnitRefname",
    "QuantityUnitShortname",
    "QuantityRefname",
    "QuantityShortname",
    "RowsalesRightsType",
    "RowsalesRightsTypeRefname",
    "RowsalesRightsTypeShortname",
    "Rate",
    "RateRefname",
    "RateShortname",
    "Rating",
    "RatingLimit",
    "RatingLimitRefname",
    "RatingLimitShortname",
    "RatingUnits",
    "RatingUnitsRefname",
    "RatingUnitsShortname",
    "RatingRefname",
    "RatingShortname",
    "RecordReference",
    "RecordReferenceRefname",
    "RecordReferenceShortname",
    "RecordSourceIdtype",
    "RecordSourceIdtypeRefname",
    "RecordSourceIdtypeShortname",
    "RecordSourceIdentifier",
    "RecordSourceIdentifierRefname",
    "RecordSourceIdentifierShortname",
    "RecordSourceName",
    "RecordSourceNameRefname",
    "RecordSourceNameShortname",
    "RecordSourceType",
    "RecordSourceTypeRefname",
    "RecordSourceTypeShortname",
    "RegionCode",
    "RegionCodeRefname",
    "RegionCodeShortname",
    "RegionsExcluded",
    "RegionsExcludedRefname",
    "RegionsExcludedShortname",
    "RegionsIncluded",
    "RegionsIncludedRefname",
    "RegionsIncludedShortname",
    "Reissue",
    "ReissueDate",
    "ReissueDateRefname",
    "ReissueDateShortname",
    "ReissueDescription",
    "ReissueDescriptionRefname",
    "ReissueDescriptionShortname",
    "ReissueRefname",
    "ReissueShortname",
    "RelatedMaterial",
    "RelatedMaterialRefname",
    "RelatedMaterialShortname",
    "RelatedProduct",
    "RelatedProductRefname",
    "RelatedProductShortname",
    "RelatedWork",
    "RelatedWorkRefname",
    "RelatedWorkShortname",
    "ReligiousText",
    "ReligiousTextFeature",
    "ReligiousTextFeatureCode",
    "ReligiousTextFeatureCodeRefname",
    "ReligiousTextFeatureCodeShortname",
    "ReligiousTextFeatureDescription",
    "ReligiousTextFeatureDescriptionRefname",
    "ReligiousTextFeatureDescriptionShortname",
    "ReligiousTextFeatureType",
    "ReligiousTextFeatureTypeRefname",
    "ReligiousTextFeatureTypeShortname",
    "ReligiousTextFeatureRefname",
    "ReligiousTextFeatureShortname",
    "ReligiousTextIdentifier",
    "ReligiousTextIdentifierRefname",
    "ReligiousTextIdentifierShortname",
    "ReligiousTextRefname",
    "ReligiousTextShortname",
    "ReprintDetail",
    "ReprintDetailRefname",
    "ReprintDetailShortname",
    "Reserved",
    "ReservedRefname",
    "ReservedShortname",
    "ResourceContentType",
    "ResourceContentTypeRefname",
    "ResourceContentTypeShortname",
    "ResourceFeature",
    "ResourceFeatureType",
    "ResourceFeatureTypeRefname",
    "ResourceFeatureTypeShortname",
    "ResourceFeatureRefname",
    "ResourceFeatureShortname",
    "ResourceFileContentDescription",
    "ResourceFileContentDescriptionRefname",
    "ResourceFileContentDescriptionShortname",
    "ResourceFileDate",
    "ResourceFileDateRole",
    "ResourceFileDateRoleRefname",
    "ResourceFileDateRoleShortname",
    "ResourceFileDateRefname",
    "ResourceFileDateShortname",
    "ResourceFileDescription",
    "ResourceFileDescriptionRefname",
    "ResourceFileDescriptionShortname",
    "ResourceFileDetail",
    "ResourceFileDetailRefname",
    "ResourceFileDetailShortname",
    "ResourceFileFeature",
    "ResourceFileFeatureDescription",
    "ResourceFileFeatureDescriptionRefname",
    "ResourceFileFeatureDescriptionShortname",
    "ResourceFileFeatureType",
    "ResourceFileFeatureTypeRefname",
    "ResourceFileFeatureTypeShortname",
    "ResourceFileFeatureValue",
    "ResourceFileFeatureValueRefname",
    "ResourceFileFeatureValueShortname",
    "ResourceFileFeatureRefname",
    "ResourceFileFeatureShortname",
    "ResourceFileLink",
    "ResourceFileLinkRefname",
    "ResourceFileLinkShortname",
    "ResourceForm",
    "ResourceFormRefname",
    "ResourceFormShortname",
    "ResourceIdtype",
    "ResourceIdtypeRefname",
    "ResourceIdtypeShortname",
    "ResourceIdentifier",
    "ResourceIdentifierRefname",
    "ResourceIdentifierShortname",
    "ResourceLink",
    "ResourceLinkRefname",
    "ResourceLinkShortname",
    "ResourceMode",
    "ResourceModeRefname",
    "ResourceModeShortname",
    "ResourceRole",
    "ResourceRoleRefname",
    "ResourceRoleShortname",
    "ResourceVersion",
    "ResourceVersionFeature",
    "ResourceVersionFeatureType",
    "ResourceVersionFeatureTypeRefname",
    "ResourceVersionFeatureTypeShortname",
    "ResourceVersionFeatureRefname",
    "ResourceVersionFeatureShortname",
    "ResourceVersionRefname",
    "ResourceVersionShortname",
    "ReturnsCode",
    "ReturnsCodeType",
    "ReturnsCodeTypeName",
    "ReturnsCodeTypeNameRefname",
    "ReturnsCodeTypeNameShortname",
    "ReturnsCodeTypeRefname",
    "ReturnsCodeTypeShortname",
    "ReturnsCodeRefname",
    "ReturnsCodeShortname",
    "ReturnsConditions",
    "ReturnsConditionsRefname",
    "ReturnsConditionsShortname",
    "ReturnsNote",
    "ReturnsNoteRefname",
    "ReturnsNoteShortname",
    "ReviewRating",
    "ReviewRatingRefname",
    "ReviewRatingShortname",
    "SalesOutlet",
    "SalesOutletIdtype",
    "SalesOutletIdtypeRefname",
    "SalesOutletIdtypeShortname",
    "SalesOutletIdentifier",
    "SalesOutletIdentifierRefname",
    "SalesOutletIdentifierShortname",
    "SalesOutletName",
    "SalesOutletNameRefname",
    "SalesOutletNameShortname",
    "SalesOutletRefname",
    "SalesOutletShortname",
    "SalesRestriction",
    "SalesRestrictionNote",
    "SalesRestrictionNoteRefname",
    "SalesRestrictionNoteShortname",
    "SalesRestrictionType",
    "SalesRestrictionTypeRefname",
    "SalesRestrictionTypeShortname",
    "SalesRestrictionRefname",
    "SalesRestrictionShortname",
    "SalesRights",
    "SalesRightsType",
    "SalesRightsTypeRefname",
    "SalesRightsTypeShortname",
    "SalesRightsRefname",
    "SalesRightsShortname",
    "ScriptCode",
    "ScriptCodeRefname",
    "ScriptCodeShortname",
    "Sender",
    "SenderIdtype",
    "SenderIdtypeRefname",
    "SenderIdtypeShortname",
    "SenderIdentifier",
    "SenderIdentifierRefname",
    "SenderIdentifierShortname",
    "SenderName",
    "SenderNameRefname",
    "SenderNameShortname",
    "SenderRefname",
    "SenderShortname",
    "SentDateTime",
    "SentDateTimeRefname",
    "SentDateTimeShortname",
    "SequenceNumber",
    "SequenceNumberRefname",
    "SequenceNumberShortname",
    "SourceName",
    "SourceNameRefname",
    "SourceNameShortname",
    "SourceTitle",
    "SourceTitleRefname",
    "SourceTitleShortname",
    "SourceType",
    "SourceTypeRefname",
    "SourceTypeShortname",
    "SpecificationBundleName",
    "SpecificationBundleNameTypeName",
    "SpecificationBundleNameTypeNameRefname",
    "SpecificationBundleNameTypeNameShortname",
    "SpecificationBundleNameValue",
    "SpecificationBundleNameValueRefname",
    "SpecificationBundleNameValueShortname",
    "SpecificationBundleNameRefname",
    "SpecificationBundleNameShortname",
    "SpecificationDescription",
    "SpecificationDescriptionRefname",
    "SpecificationDescriptionShortname",
    "SpecificationDetail",
    "SpecificationDetailRefname",
    "SpecificationDetailShortname",
    "SpecificationFeature",
    "SpecificationFeatureDescription",
    "SpecificationFeatureDescriptionRefname",
    "SpecificationFeatureDescriptionShortname",
    "SpecificationFeatureType",
    "SpecificationFeatureTypeRefname",
    "SpecificationFeatureTypeShortname",
    "SpecificationFeatureValue",
    "SpecificationFeatureValueRefname",
    "SpecificationFeatureValueShortname",
    "SpecificationFeatureRefname",
    "SpecificationFeatureShortname",
    "StartDate",
    "StartDateRefname",
    "StartDateShortname",
    "StartTime",
    "StartTimeRefname",
    "StartTimeShortname",
    "Stock",
    "StockQuantityCode",
    "StockQuantityCodeType",
    "StockQuantityCodeTypeName",
    "StockQuantityCodeTypeNameRefname",
    "StockQuantityCodeTypeNameShortname",
    "StockQuantityCodeTypeRefname",
    "StockQuantityCodeTypeShortname",
    "StockQuantityCodeRefname",
    "StockQuantityCodeShortname",
    "StockQuantityCoded",
    "StockQuantityCodedRefname",
    "StockQuantityCodedShortname",
    "StockRefname",
    "StockShortname",
    "StreetAddress",
    "StreetAddressRefname",
    "StreetAddressShortname",
    "StudyBibleType",
    "StudyBibleTypeRefname",
    "StudyBibleTypeShortname",
    "Subject",
    "SubjectCode",
    "SubjectCodeRefname",
    "SubjectCodeShortname",
    "SubjectDate",
    "SubjectDateRole",
    "SubjectDateRoleRefname",
    "SubjectDateRoleShortname",
    "SubjectDateRefname",
    "SubjectDateShortname",
    "SubjectHeadingText",
    "SubjectHeadingTextRefname",
    "SubjectHeadingTextShortname",
    "SubjectSchemeIdentifier",
    "SubjectSchemeIdentifierRefname",
    "SubjectSchemeIdentifierShortname",
    "SubjectSchemeName",
    "SubjectSchemeNameRefname",
    "SubjectSchemeNameShortname",
    "SubjectSchemeVersion",
    "SubjectSchemeVersionRefname",
    "SubjectSchemeVersionShortname",
    "SubjectRefname",
    "SubjectShortname",
    "Subtitle",
    "SubtitleRefname",
    "SubtitleShortname",
    "SuffixToKey",
    "SuffixToKeyRefname",
    "SuffixToKeyShortname",
    "SupplementManifest",
    "SupplementManifestRefname",
    "SupplementManifestShortname",
    "Supplier",
    "SupplierCodeType",
    "SupplierCodeTypeName",
    "SupplierCodeTypeNameRefname",
    "SupplierCodeTypeNameShortname",
    "SupplierCodeTypeRefname",
    "SupplierCodeTypeShortname",
    "SupplierCodeValue",
    "SupplierCodeValueRefname",
    "SupplierCodeValueShortname",
    "SupplierIdtype",
    "SupplierIdtypeRefname",
    "SupplierIdtypeShortname",
    "SupplierIdentifier",
    "SupplierIdentifierRefname",
    "SupplierIdentifierShortname",
    "SupplierName",
    "SupplierNameRefname",
    "SupplierNameShortname",
    "SupplierOwnCoding",
    "SupplierOwnCodingRefname",
    "SupplierOwnCodingShortname",
    "SupplierRole",
    "SupplierRoleRefname",
    "SupplierRoleShortname",
    "SupplierRefname",
    "SupplierShortname",
    "SupplyContact",
    "SupplyContactIdtype",
    "SupplyContactIdtypeRefname",
    "SupplyContactIdtypeShortname",
    "SupplyContactIdentifier",
    "SupplyContactIdentifierRefname",
    "SupplyContactIdentifierShortname",
    "SupplyContactName",
    "SupplyContactNameRefname",
    "SupplyContactNameShortname",
    "SupplyContactRole",
    "SupplyContactRoleRefname",
    "SupplyContactRoleShortname",
    "SupplyContactRefname",
    "SupplyContactShortname",
    "SupplyDate",
    "SupplyDateRole",
    "SupplyDateRoleRefname",
    "SupplyDateRoleShortname",
    "SupplyDateRefname",
    "SupplyDateShortname",
    "SupplyDetail",
    "SupplyDetailRefname",
    "SupplyDetailShortname",
    "SupportingResource",
    "SupportingResourceRefname",
    "SupportingResourceShortname",
    "Tax",
    "TaxAmount",
    "TaxAmountRefname",
    "TaxAmountShortname",
    "TaxExempt",
    "TaxExemptRefname",
    "TaxExemptShortname",
    "TaxRateCode",
    "TaxRateCodeRefname",
    "TaxRateCodeShortname",
    "TaxRatePercent",
    "TaxRatePercentRefname",
    "TaxRatePercentShortname",
    "TaxType",
    "TaxTypeRefname",
    "TaxTypeShortname",
    "TaxRefname",
    "TaxShortname",
    "TaxableAmount",
    "TaxableAmountRefname",
    "TaxableAmountShortname",
    "TelephoneNumber",
    "TelephoneNumberRefname",
    "TelephoneNumberShortname",
    "Territory",
    "TerritoryRefname",
    "TerritoryShortname",
    "Text",
    "TextAuthor",
    "TextAuthorRefname",
    "TextAuthorShortname",
    "TextContent",
    "TextContentRefname",
    "TextContentShortname",
    "TextItem",
    "TextItemIdtype",
    "TextItemIdtypeRefname",
    "TextItemIdtypeShortname",
    "TextItemIdentifier",
    "TextItemIdentifierRefname",
    "TextItemIdentifierShortname",
    "TextItemType",
    "TextItemTypeRefname",
    "TextItemTypeShortname",
    "TextItemRefname",
    "TextItemShortname",
    "TextSourceCorporate",
    "TextSourceCorporateRefname",
    "TextSourceCorporateShortname",
    "TextSourceDescription",
    "TextSourceDescriptionRefname",
    "TextSourceDescriptionShortname",
    "TextType",
    "TextTypeRefname",
    "TextTypeShortname",
    "TextRefname",
    "TextShortname",
    "ThesisPresentedTo",
    "ThesisPresentedToRefname",
    "ThesisPresentedToShortname",
    "ThesisType",
    "ThesisTypeRefname",
    "ThesisTypeShortname",
    "ThesisYear",
    "ThesisYearRefname",
    "ThesisYearShortname",
    "TimeRun",
    "TimeRunRefname",
    "TimeRunShortname",
    "TitleDetail",
    "TitleDetailRefname",
    "TitleDetailShortname",
    "TitleElement",
    "TitleElementLevel",
    "TitleElementLevelRefname",
    "TitleElementLevelShortname",
    "TitleElementRefname",
    "TitleElementShortname",
    "TitlePrefix",
    "TitlePrefixRefname",
    "TitlePrefixShortname",
    "TitleStatement",
    "TitleStatementRefname",
    "TitleStatementShortname",
    "TitleText",
    "TitleTextRefname",
    "TitleTextShortname",
    "TitleType",
    "TitleTypeRefname",
    "TitleTypeShortname",
    "TitleWithoutPrefix",
    "TitleWithoutPrefixRefname",
    "TitleWithoutPrefixShortname",
    "TitlesAfterNames",
    "TitlesAfterNamesRefname",
    "TitlesAfterNamesShortname",
    "TitlesBeforeNames",
    "TitlesBeforeNamesRefname",
    "TitlesBeforeNamesShortname",
    "ToLanguage",
    "ToLanguageRefname",
    "ToLanguageShortname",
    "ToQuantity",
    "ToQuantityRefname",
    "ToQuantityShortname",
    "TradeCategory",
    "TradeCategoryRefname",
    "TradeCategoryShortname",
    "UnnamedPersons",
    "UnnamedPersonsRefname",
    "UnnamedPersonsShortname",
    "UnpricedItemType",
    "UnpricedItemTypeRefname",
    "UnpricedItemTypeShortname",
    "Velocity",
    "VelocityMetric",
    "VelocityMetricRefname",
    "VelocityMetricShortname",
    "VelocityRefname",
    "VelocityShortname",
    "VenueName",
    "VenueNameRefname",
    "VenueNameShortname",
    "VenueNote",
    "VenueNoteRefname",
    "VenueNoteShortname",
    "Website",
    "WebsiteDescription",
    "WebsiteDescriptionRefname",
    "WebsiteDescriptionShortname",
    "WebsiteLink",
    "WebsiteLinkRefname",
    "WebsiteLinkShortname",
    "WebsiteRole",
    "WebsiteRoleRefname",
    "WebsiteRoleShortname",
    "WebsiteRefname",
    "WebsiteShortname",
    "WorkIdtype",
    "WorkIdtypeRefname",
    "WorkIdtypeShortname",
    "WorkIdentifier",
    "WorkIdentifierRefname",
    "WorkIdentifierShortname",
    "WorkRelationCode",
    "WorkRelationCodeRefname",
    "WorkRelationCodeShortname",
    "YearOfAnnual",
    "YearOfAnnualRefname",
    "YearOfAnnualShortname",
    "ReleaseAttributeRelease",
    "List1",
    "List100",
    "List102",
    "List12",
    "List121",
    "List13",
    "List14",
    "List141",
    "List142",
    "List144",
    "List145",
    "List146",
    "List147",
    "List148",
    "List149",
    "List15",
    "List150",
    "List151",
    "List152",
    "List153",
    "List154",
    "List155",
    "List156",
    "List157",
    "List158",
    "List159",
    "List16",
    "List160",
    "List161",
    "List162",
    "List163",
    "List164",
    "List165",
    "List166",
    "List167",
    "List168",
    "List169",
    "List17",
    "List170",
    "List171",
    "List172",
    "List173",
    "List174",
    "List175",
    "List177",
    "List179",
    "List18",
    "List19",
    "List197",
    "List198",
    "List2",
    "List20",
    "List21",
    "List215",
    "List216",
    "List217",
    "List218",
    "List219",
    "List22",
    "List228",
    "List229",
    "List23",
    "List230",
    "List239",
    "List24",
    "List240",
    "List241",
    "List244",
    "List245",
    "List246",
    "List247",
    "List248",
    "List249",
    "List25",
    "List250",
    "List252",
    "List253",
    "List254",
    "List255",
    "List27",
    "List28",
    "List29",
    "List3",
    "List30",
    "List31",
    "List32",
    "List34",
    "List41",
    "List42",
    "List43",
    "List44",
    "List45",
    "List46",
    "List48",
    "List49",
    "List5",
    "List50",
    "List51",
    "List53",
    "List55",
    "List57",
    "List58",
    "List59",
    "List60",
    "List61",
    "List62",
    "List64",
    "List65",
    "List68",
    "List69",
    "List70",
    "List71",
    "List72",
    "List73",
    "List74",
    "List79",
    "List80",
    "List81",
    "List82",
    "List83",
    "List84",
    "List85",
    "List86",
    "List87",
    "List89",
    "List9",
    "List90",
    "List91",
    "List92",
    "List93",
    "List96",
    "List97",
    "Block",
    "Flow",
    "Inline",
    "Scope",
    "Shape",
    "Tframe",
    "Trules",
    "A",
    "AContent",
    "Abbr",
    "Acronym",
    "Address",
    "Area",
    "AreaAttlistNohref",
    "B",
    "Bdo",
    "BdoAttlistDir",
    "Big",
    "Blockquote",
    "Br",
    "Caption",
    "CellhalignAlign",
    "CellvalignValign",
    "Cite",
    "Code",
    "Col",
    "Colgroup",
    "Dd",
    "Dfn",
    "Div",
    "Dl",
    "Dt",
    "Em",
    "H1",
    "H2",
    "H3",
    "H4",
    "H5",
    "H6",
    "Hr",
    "I",
    "I18NDir",
    "Img",
    "ImgAttlistIsmap",
    "Kbd",
    "Li",
    "Map",
    "Ol",
    "P",
    "Pre",
    "PreContent",
    "Q",
    "Rb",
    "Rbc",
    "Rp",
    "Rt",
    "Rtc",
    "Ruby",
    "RubyContent",
    "Samp",
    "Small",
    "Span",
    "Strong",
    "Sub",
    "Sup",
    "Table",
    "Tbody",
    "Td",
    "Tfoot",
    "Th",
    "Thead",
    "Tr",
    "Tt",
    "Ul",
    "Var",
]
